/*!***************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/assets/styles/index.scss ***!
  \***************************************************************************************************************************************************/
@charset "UTF-8";
/* latin-ext */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 100;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Thin.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 100;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Thin.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/* latin-ext */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 300;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Light.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 300;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Light.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/* latin-ext */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 400;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Regular.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 400;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Regular.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/* latin-ext */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 500;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Medium.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto;
  font-style: normal;
  font-weight: 500;
  font-display: swap;
  src: url("/assets/fonts/Roboto-Medium.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/* latin-ext */
@font-face {
  font-family: Roboto Condensed;
  font-style: normal;
  font-weight: 300;
  font-display: swap;
  src: url("/assets/fonts/RobotoCondensed-Light.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto Condensed;
  font-style: normal;
  font-weight: 300;
  font-display: swap;
  src: url("/assets/fonts/RobotoCondensed-Light.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/* latin-ext */
@font-face {
  font-family: Roboto Condensed;
  font-style: normal;
  font-weight: 400;
  font-display: swap;
  src: url("/assets/fonts/RobotoCondensed-Regular.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto Condensed;
  font-style: normal;
  font-weight: 400;
  font-display: swap;
  src: url("/assets/fonts/RobotoCondensed-Regular.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
/* latin-ext */
@font-face {
  font-family: Roboto Condensed;
  font-style: normal;
  font-weight: 700;
  font-display: swap;
  src: url("/assets/fonts/RobotoCondensed-Bold.ttf") format("opentype");
  unicode-range: U+0100-024F, U+0259, U+1E00-1EFF, U+2020, U+20A0-20AB, U+20AD-20CF, U+2113, U+2C60-2C7F, U+A720-A7FF;
}
/* latin */
@font-face {
  font-family: Roboto Condensed;
  font-style: normal;
  font-weight: 700;
  font-display: swap;
  src: url("/assets/fonts/RobotoCondensed-Bold.ttf") format("opentype");
  unicode-range: U+0000-00FF, U+0131, U+0152-0153, U+02BB-02BC, U+02C6, U+02DA, U+02DC, U+2000-206F, U+2074, U+20AC, U+2122, U+2191, U+2193, U+2212, U+2215, U+FEFF, U+FFFD;
}
html,
body,
div#index__root__uuE5N {
  height: 100%;
  left: 0;
  position: absolute;
  top: 0;
  width: 100%;
  font-family: var(--font-family), serif;
  margin: 0;
  padding: 0;
}

iframe {
  border: none;
}

a {
  text-decoration: none;
  color: unset;
}

button {
  outline: none;
  background: none;
  border: none;
  cursor: pointer;
  display: flex;
  align-items: center;
  text-decoration: none;
  padding: unset;
  font-family: var(--font-family), serif;
}
button:disabled,
button .index__disabled__zJzaS {
  cursor: not-allowed;
}

:root {
  --background-color: #2b2c32;
  --font: #fff;
  --body-font: #a5abb3;
  --sub-text-color: #a5abb3;
  --hover-grey: rgb(198 205 214 / 3%);
  --border-color: #42424c;
  --box-background: rgb(36 36 41 / 40%);
  --error: #ff2463;
  --warning-bright: #ffdb2c;
  --warning: #ac9730;
  --warning-border: #ffdb2c33;
  --font-family: "Roboto", sans-serif;
  --font-family-cond: "Roboto Condensed", monospace, serif;
  --code-background: #2b2c32;
  --code-background-hover: #36383e;
  --active-text: #2ccbe5;
  --active-hover: #2ccbe51a;
  --copy-field: #c6cdd626;
  --blue-button: #05869c;
  --blue-button-text: #fff;
  --blue-button-disabled: #42424c;
  --blue-button-disabled-text: rgb(255 255 255 / 60%);
  --secondary-blue-button: #2ccbe5;
  --secondary-blue-button-disabled: #c6cdd6;
  --outline-button: #323339;
  --outline-button-border: #42424c;
  --outline-button-text: #fff;
  --outline-button-disabled-text: #a5abb3;
  --outline-button-active: rgb(44 203 229 / 10%);
  --outline-button-active-border: #2b5964;
  --outline-button-active-text: #2ccbe5;
  --blue-icon-button-text: #2ccbe5;
  --blue-icon-button-hover-text: #94e5f2;
  --disabled-tab: rgb(43 44 50 / 50%);
  --selected-tab: #2b2c32;
  --selected-node: #414149;
  --layout-background: #212125;
  --input-background: #2a2b31;
  --input-border: #42424c;
  --input-border-active: #c6cdd6;
  --dropdown-item-hover: #2ccbe51a;
  --checkbox-background: #c6cdd60d;
  --checkbox-border: #42424c;
  --checkbox-hover-border: #94e5f2;
  --checkbox-active-background: #2bcbe4;
  --menu-background: #212125;
  --menu-text-color: #c6cdd6;
  --menu-hover-text: #242c32;
  --menu-accent-color: #2ccbe5;
  --admin-header-background: #242429;
  --icon-thumbnail: #42424c;
  --log-background: #1e1e1e;
  --log-color: #fff;
  --popup-background: #323339;
  --overlay-background: #212125cc;
  --overlay-background-blocking: #212125;
  --label-background: #484a50;
  --tooltip: #2a2b31;
  --tooltip-border: #42424c;
  --tooltip-shadow: 0px 4px 8px rgb(0 0 0 / 25%);
  --table-header: #323339;
  --table-background: #2b2c32;
  --table-hover: #2b2c32;
  --table-active-background: rgb(44 203 229 / 5%);
  --job-list-header: #212125;
  --job-list-background: #242429;
  --selection-color: rgb(198 205 214 / 3%);
  --grouping-border: rgb(198 205 214 / 60%);
  --grouping-border-hover: rgb(198 205 214 / 100%);
  --grouping-border-active: #fff;
  --green: #bdff94;
  --green-light: #2e392d;
  --yellow: #fed465;
  --yellow-light: #403931;
  --blue: #81e1ff;
  --blue-light: #2e3846;
  --red: #ff8484;
  --red-light: #40333a;
  --grey: #c6cdd6;
  --grey-light: #37393f;
  --tag-hover-color: #2b444d;
  --popup-fade-wrapper: rgb(33 33 37 / 80%);
  --action-button-hover: #31424a;
  --action-button-hover-border: #2f7988;
  --color-splitter: #212125;
  --color-splitter-hover: #2b444d;
}

::-webkit-scrollbar {
  display: none;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  margin: 0;
  padding: 0;
  font-size: 1em;
  font-weight: normal;
  line-height: normal;
}

p {
  font-weight: normal;
  margin: unset;
}

input::placeholder {
  color: var(--sub-text-color);
  letter-spacing: 0.06em;
}

select {
  color: var(--sub-text-color);
  -webkit-appearance: none;
  appearance: none;
  position: relative;
  width: 100%;
}

input[type=checkbox] {
  background: var(--checkbox-background);
  border: 1px solid var(--border-color);
  box-sizing: border-box;
  border-radius: 2px;
  height: 18px;
  width: 18px;
  -webkit-appearance: none;
  -moz-appearance: none;
  appearance: none;
  box-shadow: none;
  font-size: 1.4em;
  line-height: 1.5em;
  cursor: pointer;
  position: relative;
}

input[type=checkbox]:checked {
  background: var(--secondary-blue-button);
  position: relative;
}
input[type=checkbox]:checked::after {
  height: 100%;
  width: 100%;
  content: "✓";
  color: var(--popup-background);
  font-size: 0.6em;
  position: absolute;
  top: -6px;
  left: 3px;
  font-weight: 700;
}

fieldset {
  border: none;
  padding: 0;
}

foreignobject {
  y: 15;
  x: 0;
  color: grey;
}
/*!***************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/assets/styles/_base.scss ***!
  \***************************************************************************************************************************************************/

/*!*****************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[4].use[2]!./node_modules/flexlayout-react/style/light.css ***!
  \*****************************************************************************************************************************/
.flexlayout__layout {
  --color-text: black;
  --color-background: white;
  --color-base: white;
  --color-1: #f7f7f7;
  --color-2: #f0f0f0;
  --color-3: #e9e9e9;
  --color-4: #e2e2e2;
  --color-5: #dbdbdb;
  --color-6: #d4d4d4;
  --color-drag1: rgb(95, 134, 196);
  --color-drag2: rgb(119, 166, 119);
  --color-drag1-background: rgba(95, 134, 196, 0.1);
  --color-drag2-background: rgba(119, 166, 119, 0.075);
  --font-size: medium;
  --font-family: Roboto, Arial, sans-serif;
  --color-overflow: gray;
  --color-icon: gray;
  --color-tabset-background: var(--color-background);
  --color-tabset-background-selected: var(--color-1);
  --color-tabset-background-maximized: var(--color-6);
  --color-tabset-divider-line: var(--color-4);
  --color-tabset-header-background: var(--color-background);
  --color-tabset-header: var(--color-text);
  --color-border-background: var(--color-background);
  --color-border-divider-line: var(--color-4);
  --color-tab-selected: var(--color-text);
  --color-tab-selected-background: var(--color-4);
  --color-tab-unselected: gray;
  --color-tab-unselected-background: transparent;
  --color-tab-textbox: var(--color-text);
  --color-tab-textbox-background: var(--color-3);
  --color-border-tab-selected: var(--color-text);
  --color-border-tab-selected-background: var(--color-4);
  --color-border-tab-unselected: gray;
  --color-border-tab-unselected-background: var(--color-2);
  --color-splitter: var(--color-1);
  --color-splitter-hover: var(--color-4);
  --color-splitter-drag: var(--color-4);
  --color-drag-rect-border: var(--color-6);
  --color-drag-rect-background: var(--color-4);
  --color-drag-rect: var(--color-text);
  --color-popup-border: var(--color-6);
  --color-popup-unselected: var(--color-text);
  --color-popup-unselected-background: white;
  --color-popup-selected: var(--color-text);
  --color-popup-selected-background: var(--color-3);
  --color-edge-marker: #aaa;
  --color-edge-icon: #555;
}

.flexlayout__layout {
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  position: absolute;
  overflow: hidden;
}
.flexlayout__splitter {
  background-color: var(--color-splitter);
}
@media (hover: hover) {
  .flexlayout__splitter:hover {
    background-color: var(--color-splitter-hover);
    transition: background-color ease-in 0.1s;
    transition-delay: 0.05s;
  }
}
.flexlayout__splitter_border {
  z-index: 10;
}
.flexlayout__splitter_drag {
  z-index: 1000;
  background-color: var(--color-splitter-drag);
}
.flexlayout__splitter_extra {
  background-color: transparent;
}
.flexlayout__outline_rect {
  position: absolute;
  pointer-events: none;
  box-sizing: border-box;
  border: 2px solid var(--color-drag1);
  background: var(--color-drag1-background);
  border-radius: 5px;
  z-index: 1000;
}
.flexlayout__outline_rect_edge {
  pointer-events: none;
  border: 2px solid var(--color-drag2);
  background: var(--color-drag2-background);
  border-radius: 5px;
  z-index: 1000;
  box-sizing: border-box;
}
.flexlayout__edge_rect {
  position: absolute;
  z-index: 1000;
  background-color: var(--color-edge-marker);
  pointer-events: none;
  display: flex;
  align-items: center;
  justify-content: center;
}
.flexlayout__drag_rect {
  position: absolute;
  cursor: move;
  color: var(--color-drag-rect);
  background-color: var(--color-drag-rect-background);
  border: 2px solid var(--color-drag-rect-border);
  border-radius: 5px;
  z-index: 1000;
  box-sizing: border-box;
  opacity: 0.9;
  text-align: center;
  display: flex;
  justify-content: center;
  flex-direction: column;
  overflow: hidden;
  padding: 0.3em 1em;
  word-wrap: break-word;
  font-size: var(--font-size);
  font-family: var(--font-family);
}
.flexlayout__tabset {
  display: flex;
  flex-direction: column;
  overflow: hidden;
  background-color: var(--color-tabset-background);
  box-sizing: border-box;
  font-size: var(--font-size);
  font-family: var(--font-family);
}
.flexlayout__tabset_tab_divider {
  width: 4px;
}
.flexlayout__tabset_content {
  display: flex;
  flex-grow: 1;
  align-items: center;
  justify-content: center;
}
.flexlayout__tabset_header {
  display: flex;
  align-items: center;
  padding: 3px 3px 3px 5px;
  box-sizing: border-box;
  border-bottom: 1px solid var(--color-tabset-divider-line);
  color: var(--color-tabset-header);
  background-color: var(--color-tabset-header-background);
}
.flexlayout__tabset_header_content {
  flex-grow: 1;
}
.flexlayout__tabset_tabbar_outer {
  box-sizing: border-box;
  background-color: var(--color-tabset-background);
  overflow: hidden;
  display: flex;
}
.flexlayout__tabset_tabbar_outer_top {
  border-bottom: 1px solid var(--color-tabset-divider-line);
}
.flexlayout__tabset_tabbar_outer_bottom {
  border-top: 1px solid var(--color-tabset-divider-line);
}
.flexlayout__tabset_tabbar_inner {
  position: relative;
  box-sizing: border-box;
  display: flex;
  flex-grow: 1;
  overflow: hidden;
}
.flexlayout__tabset_tabbar_inner_tab_container {
  display: flex;
  padding-left: 4px;
  padding-right: 4px;
  box-sizing: border-box;
  position: absolute;
  top: 0;
  bottom: 0;
  width: 10000px;
}
.flexlayout__tabset_tabbar_inner_tab_container_top {
  border-top: 2px solid transparent;
}
.flexlayout__tabset_tabbar_inner_tab_container_bottom {
  border-bottom: 2px solid transparent;
}
.flexlayout__tabset-selected {
  background-color: var(--color-tabset-background-selected);
}
.flexlayout__tabset-maximized {
  background-color: var(--color-tabset-background-maximized);
}
.flexlayout__tab_button_stamp {
  display: inline-flex;
  align-items: center;
  gap: 0.3em;
  white-space: nowrap;
  box-sizing: border-box;
}
.flexlayout__tab {
  overflow: auto;
  position: absolute;
  box-sizing: border-box;
  background-color: var(--color-background);
  color: var(--color-text);
}
.flexlayout__tab_button {
  display: flex;
  gap: 0.3em;
  align-items: center;
  box-sizing: border-box;
  padding: 3px 0.5em;
  cursor: pointer;
}
.flexlayout__tab_button_stretch {
  background-color: transparent;
  color: var(--color-tab-selected);
  width: 100%;
  padding: 3px 0em;
  text-wrap: nowrap;
  display: flex;
  gap: 0.3em;
  align-items: center;
  box-sizing: border-box;
  cursor: pointer;
}
@media (hover: hover) {
  .flexlayout__tab_button_stretch:hover {
    color: var(--color-tab-selected);
  }
}
.flexlayout__tab_button--selected {
  background-color: var(--color-tab-selected-background);
  color: var(--color-tab-selected);
}
@media (hover: hover) {
  .flexlayout__tab_button:hover {
    background-color: var(--color-tab-selected-background);
    color: var(--color-tab-selected);
  }
}
.flexlayout__tab_button--unselected {
  background-color: var(--color-tab-unselected-background);
  color: var(--color-tab-unselected);
  color: gray;
}
.flexlayout__tab_button_leading {
  display: flex;
}
.flexlayout__tab_button_content {
  display: flex;
}
.flexlayout__tab_button_textbox {
  border: none;
  font-family: var(--font-family);
  font-size: var(--font-size);
  color: var(--color-tab-textbox);
  background-color: var(--color-tab-textbox-background);
  border: 1px inset var(--color-1);
  border-radius: 3px;
  width: 10em;
}
.flexlayout__tab_button_textbox:focus {
  outline: none;
}
.flexlayout__tab_button_trailing {
  display: flex;
  visibility: hidden;
  border-radius: 4px;
}
.flexlayout__tab_button_trailing:hover {
  background-color: var(--color-3);
}
@media (hover: hover) {
  .flexlayout__tab_button:hover .flexlayout__tab_button_trailing {
    visibility: visible;
  }
}
.flexlayout__tab_button--selected .flexlayout__tab_button_trailing {
  visibility: visible;
}
.flexlayout__tab_button_overflow {
  display: flex;
  align-items: center;
  border: none;
  color: var(--color-overflow);
  font-size: inherit;
  background-color: transparent;
}
.flexlayout__tab_toolbar {
  display: flex;
  align-items: center;
  gap: 0.3em;
  padding-left: 0.5em;
  padding-right: 0.3em;
}
.flexlayout__tab_toolbar_button {
  border: none;
  outline: none;
  font-size: inherit;
  margin: 0px;
  background-color: transparent;
  border-radius: 4px;
  padding: 1px;
}
@media (hover: hover) {
  .flexlayout__tab_toolbar_button:hover {
    background-color: var(--color-2);
  }
}
.flexlayout__tab_toolbar_sticky_buttons_container {
  display: flex;
  gap: 0.3em;
  padding-left: 5px;
  align-items: center;
}
.flexlayout__tab_floating {
  overflow: auto;
  position: absolute;
  box-sizing: border-box;
  color: var(--color-text);
  background-color: var(--color-background);
  display: flex;
  justify-content: center;
  align-items: center;
}
.flexlayout__tab_floating_inner {
  overflow: auto;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.flexlayout__tab_floating_inner div {
  margin-bottom: 5px;
  text-align: center;
}
.flexlayout__tab_floating_inner div a {
  color: royalblue;
}
.flexlayout__border {
  box-sizing: border-box;
  overflow: hidden;
  display: flex;
  font-size: var(--font-size);
  font-family: var(--font-family);
  color: var(--color-border);
  background-color: var(--color-border-background);
}
.flexlayout__border_top {
  border-bottom: 1px solid var(--color-border-divider-line);
  align-items: center;
}
.flexlayout__border_bottom {
  border-top: 1px solid var(--color-border-divider-line);
  align-items: center;
}
.flexlayout__border_left {
  border-right: 1px solid var(--color-border-divider-line);
  align-content: center;
  flex-direction: column;
}
.flexlayout__border_right {
  border-left: 1px solid var(--color-border-divider-line);
  align-content: center;
  flex-direction: column;
}
.flexlayout__border_inner {
  position: relative;
  box-sizing: border-box;
  display: flex;
  overflow: hidden;
  flex-grow: 1;
}
.flexlayout__border_inner_tab_container {
  white-space: nowrap;
  display: flex;
  padding-left: 2px;
  padding-right: 2px;
  box-sizing: border-box;
  position: absolute;
  top: 0;
  bottom: 0;
  width: 10000px;
}
.flexlayout__border_inner_tab_container_right {
  transform-origin: top left;
  transform: rotate(90deg);
}
.flexlayout__border_inner_tab_container_left {
  flex-direction: row-reverse;
  transform-origin: top right;
  transform: rotate(-90deg);
}
.flexlayout__border_tab_divider {
  width: 4px;
}
.flexlayout__border_button {
  display: flex;
  gap: 0.3em;
  align-items: center;
  cursor: pointer;
  padding: 3px 0.5em;
  margin: 2px 0px;
  box-sizing: border-box;
  white-space: nowrap;
}
.flexlayout__border_button--selected {
  background-color: var(--color-border-tab-selected-background);
  color: var(--color-border-tab-selected);
}
@media (hover: hover) {
  .flexlayout__border_button:hover {
    background-color: var(--color-border-tab-selected-background);
    color: var(--color-border-tab-selected);
  }
}
.flexlayout__border_button--unselected {
  background-color: var(--color-border-tab-unselected-background);
  color: var(--color-border-tab-unselected);
}
.flexlayout__border_button_leading {
  display: flex;
}
.flexlayout__border_button_content {
  display: flex;
}
.flexlayout__border_button_trailing {
  display: flex;
  border-radius: 4px;
  visibility: hidden;
}
.flexlayout__border_button_trailing:hover {
  background-color: var(--color-3);
}
@media (hover: hover) {
  .flexlayout__border_button:hover .flexlayout__border_button_trailing {
    visibility: visible;
  }
}
.flexlayout__border_button--selected .flexlayout__border_button_trailing {
  visibility: visible;
}
.flexlayout__border_toolbar {
  display: flex;
  gap: 0.3em;
  align-items: center;
}
.flexlayout__border_toolbar_left, .flexlayout__border_toolbar_right {
  flex-direction: column;
  padding-top: 0.5em;
  padding-bottom: 0.3em;
}
.flexlayout__border_toolbar_top, .flexlayout__border_toolbar_bottom {
  padding-left: 0.5em;
  padding-right: 0.3em;
}
.flexlayout__border_toolbar_button {
  border: none;
  outline: none;
  font-size: inherit;
  background-color: transparent;
  border-radius: 4px;
  padding: 1px;
}
@media (hover: hover) {
  .flexlayout__border_toolbar_button:hover {
    background-color: var(--color-2);
  }
}
.flexlayout__border_toolbar_button_overflow {
  display: flex;
  align-items: center;
  border: none;
  color: var(--color-overflow);
  font-size: inherit;
  background-color: transparent;
}
.flexlayout__popup_menu {
  font-size: var(--font-size);
  font-family: var(--font-family);
}
.flexlayout__popup_menu_item {
  padding: 2px 0.5em;
  white-space: nowrap;
  cursor: pointer;
  border-radius: 2px;
}
@media (hover: hover) {
  .flexlayout__popup_menu_item:hover {
    background-color: var(--color-6);
  }
}
.flexlayout__popup_menu_container {
  box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.15);
  border: 1px solid var(--color-popup-border);
  color: var(--color-popup-unselected);
  background: var(--color-popup-unselected-background);
  border-radius: 3px;
  position: absolute;
  z-index: 1000;
  max-height: 50%;
  min-width: 100px;
  overflow: auto;
  padding: 2px;
}
.flexlayout__floating_window _body {
  height: 100%;
}
.flexlayout__floating_window_content {
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  position: absolute;
}
.flexlayout__floating_window_tab {
  overflow: auto;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  position: absolute;
  box-sizing: border-box;
  background-color: var(--color-background);
  color: var(--color-text);
}
.flexlayout__error_boundary_container {
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  position: absolute;
  display: flex;
  justify-content: center;
}
.flexlayout__error_boundary_content {
  display: flex;
  align-items: center;
}
.flexlayout__tabset_sizer {
  padding-top: 5px;
  padding-bottom: 3px;
  font-size: var(--font-size);
  font-family: var(--font-family);
}
.flexlayout__tabset_header_sizer {
  padding-top: 3px;
  padding-bottom: 3px;
  font-size: var(--font-size);
  font-family: var(--font-family);
}
.flexlayout__border_sizer {
  padding-top: 6px;
  padding-bottom: 5px;
  font-size: var(--font-size);
  font-family: var(--font-family);
}

/*# sourceMappingURL=light.css.map */

/*!*******************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/ui-lib/layouts/styles/Layout.module.scss ***!
  \*******************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.Layout-module__wrapper__dwBIY {
  display: flex;
  background-color: var(--background-color);
  color: var(--font);
}

.Layout-module__pageWrapper__fYard {
  height: 100%;
  width: 100%;
  display: flex;
  flex-direction: row;
}

.Layout-module__pageWrapper1__qtBbb {
  height: 100%;
  width: 100%;
  display: flex;
  flex-direction: column;
}

.Layout-module__mainPageWrapper__R9l7F {
  height: 100%;
  width: 100%;
  display: flex;
  flex-direction: column;
}

.Layout-module__mainPageWrapperWithSidePanelBar__vETeO {
  display: flex;
  width: 100%;
}

.Layout-module__content__xmcPT {
  flex: 1;
  display: flex;
  flex-direction: column;
}

.Layout-module__addLeftMargin__gDC5n {
  margin-left: 3px;
}

.Layout-module__layout__tsOFN {
  flex: 1;
  position: relative;
  height: 100%;
  --color-text: black;
  --color-background: var(--selected-tab);
  --color-base: white;
  --color-1: var(--layout-background);
  --color-2: #f0f0f0;
  --color-3: #e9e9e9;
  --color-4: #e2e2e2;
  --color-5: #dbdbdb;
  --color-6: #d4d4d4;
  --color-drag1: #5f86c4;
  --color-drag2: #77a677;
  --color-drag1-background: rgb(95 134 196 / 10%);
}

.Layout-module__header__DYaLO {
  display: none;
  background-color: var(--layout-background) !important;
  border: none !important;
}

.Layout-module__header_panel__JT_tZ {
  border-top: 6px solid transparent;
  border-radius: 15px 15px 0 0;
}

.Layout-module__header_panel_widget__zJ3J_ {
  justify-content: space-between;
  border-radius: 5px 5px 0 0;
  background-color: var(--disabled-tab) !important;
  color: var(--font) !important;
  border-bottom: 2px solid var(--layout-background);
  min-width: 100px;
  padding: 5px 12px;
  position: relative;
  right: 5px;
  text-align: center;
  text-transform: capitalize;
  font-size: 0.8em;
}
.Layout-module__header_panel_widget__zJ3J_:hover {
  color: var(--font) !important;
  background-color: var(--input-background) !important;
}

.Layout-module__header_panel_widget_selected__jJupV {
  background: var(--background-color) !important;
  color: var(--sub-text-color);
  border-bottom: unset;
}

.Layout-module___tabset_header_sizer__KlGEK {
  display: none;
}

.Layout-module__emptyPlaceholder__hmwwo {
  height: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
}
/*!**************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Project/Project.module.scss ***!
  \**************************************************************************************************************************************************************/
.Project-module__projectPageLayout__oU5xu {
  position: relative;
  background-color: var(--background-color);
  padding: 50px 70px;
}
@media (width <= 900px) {
  .Project-module__projectPageLayout__oU5xu {
    padding: 40px 30px;
  }
}
@media (width <= 700px) {
  .Project-module__projectPageLayout__oU5xu {
    padding: 30px 20px;
  }
}

.Project-module__pageWrapper__VcF18 {
  position: relative;
  display: flex;
  flex: 1;
  gap: 70px;
}

.Project-module__pageActions__g6ghw {
  display: flex;
  column-gap: 30px;
  position: absolute;
  bottom: 50px;
  left: 70px;
}

.Project-module__searchProjectField__tOHkK {
  margin-bottom: 18px;
}

.Project-module__actionButton__sMIPT {
  width: 172px;
  justify-content: center;
  padding: 0;
  gap: 8px;
}
/*!**************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/ui-lib/components/Button/BlueButton.module.scss ***!
  \**************************************************************************************************************************************************************************/
.BlueButton-module__blueButton__Mcy_3 {
  display: flex;
  justify-content: center;
  height: 28px;
  padding: 0 14px;
  border-radius: 45px;
  font-weight: 500;
  font-family: var(--font-family), serif;
  font-style: normal;
  font-size: 14px;
}
.BlueButton-module__blueButton__Mcy_3.BlueButton-module__big__uEHFL {
  height: 38px;
}
.BlueButton-module__blueButton__Mcy_3:disabled {
  cursor: not-allowed;
}
.BlueButton-module__blueButton__Mcy_3.BlueButton-module__isCircle__dfJ8K {
  width: 28px;
  padding: unset;
  display: flex;
  align-items: center;
  justify-content: center;
}

.BlueButton-module__primary___o883 {
  background: var(--blue-button);
  color: var(--blue-button-text);
}
.BlueButton-module__primary___o883:disabled {
  background: var(--blue-button-disabled);
  color: var(--blue-button-disabled-text);
}

.BlueButton-module__secondary__qWnMI {
  background: none;
  border: 1px solid var(--secondary-blue-button);
  color: var(--secondary-blue-button);
}
.BlueButton-module__secondary__qWnMI:disabled {
  border: 1px solid var(--secondary-blue-button-disabled);
  color: var(--secondary-blue-button-disabled);
}
/*!***************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/buttons/styles/ActionButton.module.scss ***!
  \***************************************************************************************************************************************************************************************/
.ActionButton-module__actionButton__vGRH_ {
  background-color: var(--popup-background);
  font-weight: 500;
  font-family: var(--font-family), serif;
  height: 34px;
  border-radius: 40px;
  border: 1px solid var(--border-color);
  padding: 6px 16px;
  color: var(--font);
  gap: 10px;
}
/*!**************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/buttons/styles/PlainButton.module.scss ***!
  \**************************************************************************************************************************************************************************************/
.PlainButton-module__plainButton__YIpxO {
  color: var(--font);
  background: none;
  border: none;
}
/*!****************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/buttons/styles/ButtonWrapper.module.scss ***!
  \****************************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.ButtonWrapper-module__button__JNtWR {
  font-size: 1em;
  line-height: 35px;
  cursor: pointer;
  white-space: nowrap;
  display: flex;
  align-items: center;
  gap: 16px;
}
.ButtonWrapper-module__button__JNtWR svg {
  color: inherit;
}
/*!*************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Project/components/Project.module.scss ***!
  \*************************************************************************************************************************************************************************/
.Project-module__projectActions__eGQL5 {
  opacity: 0;
}

.Project-module__project_active__jfKIm {
  background-color: var(--selection-color);
}
.Project-module__project_active__jfKIm .Project-module__projectActions__eGQL5 {
  opacity: 1;
}

.Project-module__project__qJPVU {
  display: flex;
  align-items: center;
  justify-content: space-between;
  width: 100%;
  font-size: 16px;
  height: 70px;
  padding-right: 16px;
}
.Project-module__project__qJPVU:hover {
  background-color: var(--selection-color);
}
.Project-module__project__qJPVU:hover .Project-module__projectActions__eGQL5 {
  opacity: 1;
}

.Project-module__projectInfo__rjh_z {
  display: flex;
  column-gap: 18px;
}

.Project-module__projectDetails__G5Bxn {
  display: flex;
  flex-direction: column;
  justify-content: center;
  row-gap: 8px;
}

.Project-module__projectName__ys8ww {
  color: var(--active-text);
  font-weight: 500;
}

.Project-module__projectDate__xIx5d {
  font-weight: 400;
  font-size: 12px;
  color: var(--sub-text-color);
}

.Project-module__projectThumbnail__edkv3 {
  display: flex;
  align-items: center;
  justify-content: center;
  position: relative;
  height: 38px;
  width: 38px;
}

.Project-module__projectThumbnailBackground__uSCl6 {
  position: absolute;
  height: 100%;
  width: 100%;
  border-radius: 4px;
  background-color: #d86aff;
  opacity: 0.15;
}

.Project-module__splash__B6dfy {
  height: 100%;
}
/*!******************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/common/Input/Input.module.scss ***!
  \******************************************************************************************************************************************************************************/
@charset "UTF-8";
.Input-module__inputWrapper__Cg9RV {
  position: relative;
  width: inherit;
}
.Input-module__inputWrapper__Cg9RV.Input-module__withIcon__yyITZ input {
  padding-left: 40px;
}

.Input-module__disabledInput__z1ohK {
  cursor: not-allowed;
  opacity: 0.6;
}

.Input-module__inputIcon__Sb8k7 {
  position: relative;
  bottom: 11px;
  transform: translateY(50%);
}

.Input-module__input__Q54Xd {
  height: 40px;
  box-sizing: border-box;
  padding: 12px 14px;
  border: 1px solid var(--input-border);
  border-radius: 4px;
  font-size: 0.875rem;
  line-height: 1rem;
  background: var(--input-background);
  color: var(--font);
  outline: none;
  width: 100%;
  letter-spacing: 0.05em;
}
.Input-module__input__Q54Xd:focus {
  border: 1px solid var(--input-outline);
}
.Input-module__input__Q54Xd.Input-module__error__NnFef {
  border: 1px solid rgba(255, 36, 99, 0.3);
}

.Input-module__label__L5QZt {
  color: var(--body-font);
}

.Input-module__inputTitle__wYSrG {
  color: var(--sub-text-color);
  display: flex;
  align-items: center;
  column-gap: 10px;
  margin-bottom: 8px;
  position: relative;
  white-space: nowrap;
}

.Input-module__inputController__l87RR {
  flex: 1;
  display: flex;
  align-items: center;
  gap: 15px 40px;
  margin-bottom: 30px;
  flex-wrap: wrap;
}
.Input-module__inputController__l87RR.Input-module__withIcon__yyITZ {
  display: block;
}
.Input-module__inputController__l87RR.Input-module__withIcon__yyITZ > .Input-module__inputTitle__wYSrG {
  padding-bottom: 5px;
  font-size: 14px;
}
.Input-module__inputController__l87RR.Input-module__newLineBetween__ATK5D {
  display: unset;
}

.Input-module__inputControllerWithLock__ndszn {
  margin-bottom: 70px;
}

.Input-module__inputName__zrld5:not(:empty) {
  width: 85px;
}

.Input-module__inputField__zu7tE {
  flex: 1;
  position: relative;
  height: 40px;
}

.Input-module__inputSelect__m4voi::after {
  content: "▼";
  font-size: 1rem;
  top: 10px;
  right: 10px;
  position: absolute;
}

.Input-module__addBottomPadding__caVLB {
  padding-bottom: 30px;
}

.Input-module__lockValue__uoiBj {
  flex: 150px;
  display: flex;
  align-items: center;
  margin-top: 15px;
  column-gap: 10px;
  color: var(--sub-text-color);
  font-size: 0.875rem;
}

.Input-module__errorMsg__Pl9LW {
  position: absolute;
  bottom: -20px;
  line-height: 14px;
  color: var(--error);
  font-weight: 400;
  font-size: 12px;
}

.Input-module__inputIcon_inner__oS8YJ {
  position: absolute;
  bottom: 19px;
  left: 10px;
}

.Input-module__labelWrapper__XyzvV {
  display: flex;
  width: fit-content;
  flex-direction: row-reverse;
  align-items: center;
  justify-content: center;
  gap: 10px;
  margin-bottom: 5px;
  font-size: 14px;
}
/*!***************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/ui-lib/loader/LoaderPage.module.scss ***!
  \***************************************************************************************************************************************************************/
.LoaderPage-module__container__q05cm {
  width: 100%;
  height: 900px;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  background: var(--background-color);
}

.LoaderPage-module__text__ezOMt {
  width: 100%;
  font-family: Roboto, serif;
  font-style: normal;
  font-weight: 400;
  font-size: 16px;
  line-height: 24px;
  text-align: center;
  white-space: pre-wrap;
  color: var(--sub-text-color);
}
/*!****************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/common/Page/Page.module.scss ***!
  \****************************************************************************************************************************************************************************/
.Page-module__pageName__dr7L_ {
  font-size: 24px;
  font-weight: 400;
  color: var(--font);
  font-family: var(--font-family-cond), serif;
  padding-right: 10px;
  padding-left: 30px;
  align-self: center;
  white-space: nowrap;
}

.Page-module__pageSection__gVt0c {
  position: relative;
  flex: 1;
  display: flex;
  flex-direction: column;
  column-gap: 20px;
}

.Page-module__sectionName__a5ACz {
  font-size: 16px;
  color: var(--sub-text-color);
  margin-bottom: 24px;
}

.Page-module__sectionContent__AV2YV {
  height: 100%;
}
/*!***********************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphStatus/components/MeasurementElement/MeasurementElement.module.scss ***!
  \***********************************************************************************************************************************************************************************************************************************/
.MeasurementElement-module__rowWrapper__Z9Ylt {
  background-color: var(--job-list-background);
  display: flex;
  flex-direction: column;
  border: 1px solid var(--border-color);
  border-radius: 8px;
  margin: 0.5px 0;
  padding: 6px;
  transition: all 0.3s ease;
}
.MeasurementElement-module__rowWrapper__Z9Ylt:hover {
  box-shadow: 0 4px 10px rgba(124, 122, 122, 0.5);
}

.MeasurementElement-module__row__VwLel {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 5px 0;
  font-size: 14px;
}

.MeasurementElement-module__dot__e8Vv3 {
  width: 10px;
  height: 10px;
  border-radius: 50%;
  margin-right: 8px;
  background-color: #40a8f5;
}

.MeasurementElement-module__titleOrName__bGD6X {
  font-size: 14px;
  flex: 1;
  cursor: pointer;
}

.MeasurementElement-module__descriptionWrapper__DEYuf {
  padding-left: 10px;
  padding-right: 10px;
  align-content: center;
  text-align: right;
  margin-top: 5px;
}

.MeasurementElement-module__descriptionTooltip__ufE0P {
  overflow: scroll;
  max-height: 500px;
  white-space: pre-line;
  border-radius: 6px;
}

.MeasurementElement-module__expandedContent__fkJJa {
  padding: 15px;
  border-radius: 8px;
}

.MeasurementElement-module__runInfoAndParameters__w5kWR {
  display: flex;
  gap: 20px;
  flex-wrap: wrap;
  justify-content: space-between;
  align-items: stretch;
}

.MeasurementElement-module__runInfo__Cg6fX {
  flex: 1;
  min-width: 260px;
  max-width: 100%;
  border: 2px solid var(--border-color);
  border-radius: 10px;
  padding: 15px;
  display: flex;
  flex-direction: column;
  justify-content: space-evenly;
  height: 110px;
  background-color: var(--popup-background);
}

.MeasurementElement-module__parameters__MFnNV {
  flex: 1;
  min-width: 260px;
  max-width: 100%;
  border: 2px solid var(--border-color);
  border-radius: 10px;
  padding: 15px;
  display: flex;
  flex-direction: column;
  gap: 4px;
  background-color: var(--popup-background);
}
/*!*********************************************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphStatus/components/MeasurementElementInfoSection/MeasurementElementInfoSection.module.scss ***!
  \*********************************************************************************************************************************************************************************************************************************************************/
.MeasurementElementInfoSection-module__sectionTitle__yftGx {
  font-size: 16px;
  margin-bottom: 4px;
  color: #A5ACB6;
}

.MeasurementElementInfoSection-module__infoContent__zQgcq {
  display: flex;
  flex-direction: column;
  gap: 6px;
}

.MeasurementElementInfoSection-module__infoItem__beGH7 {
  display: grid;
  grid-template-columns: max-content auto;
  align-items: center;
  gap: 10px;
  white-space: nowrap;
}

.MeasurementElementInfoSection-module__label__rjBZa {
  color: #A5ACB6;
  min-width: 130px;
}
.MeasurementElementInfoSection-module__label__rjBZa.MeasurementElementInfoSection-module__info__K8ryw {
  white-space: nowrap;
  min-width: 90px;
}

.MeasurementElementInfoSection-module__value__vtCn5 {
  color: #fff;
  text-align: left;
  white-space: nowrap;
}

.MeasurementElementInfoSection-module__outcomes__jB4uC {
  margin-top: 15px;
  border: 2px solid var(--border-color);
  border-radius: 10px;
  padding: 15px;
  background-color: var(--popup-background);
}

.MeasurementElementInfoSection-module__outcomes__jB4uC h4 {
  font-size: 16px;
  margin-bottom: 10px;
  color: var(--primary-color);
}

.MeasurementElementInfoSection-module__outcomeContainer__aRWQN {
  display: flex;
  gap: 10px;
  flex-wrap: wrap;
}

.MeasurementElementInfoSection-module__outcomeBubble__UbRAB {
  display: flex;
  align-items: center;
  border-radius: 15px;
  font-size: 12px;
  overflow: hidden;
  min-width: 90px;
  height: 24px;
  text-align: center;
  background: inherit;
}

.MeasurementElementInfoSection-module__outcomeBubble__UbRAB.MeasurementElementInfoSection-module__success__YN_cE {
  background-color: rgba(40, 167, 69, 0.3);
}

.MeasurementElementInfoSection-module__outcomeBubble__UbRAB.MeasurementElementInfoSection-module__failure__k9mUb {
  background-color: rgba(220, 53, 69, 0.3);
  min-width: 70px;
}

.MeasurementElementInfoSection-module__qubitLabel__v88qd {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100%;
  padding: 0 6px;
  font-size: 12px;
  color: #fff;
  border-radius: 15px 0 0 15px;
}

.MeasurementElementInfoSection-module__qubitLabel__v88qd.MeasurementElementInfoSection-module__success__YN_cE {
  background-color: rgba(41, 166, 70, 0.5);
}

.MeasurementElementInfoSection-module__qubitLabel__v88qd.MeasurementElementInfoSection-module__failure__k9mUb {
  background-color: rgba(220, 53, 69, 0.5);
}

.MeasurementElementInfoSection-module__outcomeStatus__pJfap {
  flex: 1;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 12px;
  padding: 0 8px;
  border-radius: 0 15px 15px 0;
}
/*!**************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Nodes/NodesPage.module.scss ***!
  \**************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.NodesPage-module__wrapper__ZG0gs {
  display: flex;
  height: 100%;
  width: 100%;
  background: var(--background-color);
  border-radius: var(--border-radius);
}

.NodesPage-module__nodesAndRunningJobInfoWrapper__Dx8jY {
  display: flex;
  width: 100%;
  overflow-y: hidden;
}

.NodesPage-module__nodesContainerTop__SAeZK {
  display: flex;
  flex-direction: column;
  width: 100%;
  max-width: 500px;
  overflow: hidden;
  flex-grow: 1;
  color: rgb(217, 213, 212);
  background-color: var(--background-color);
}

.NodesPage-module__nodesContainerDown__bG3YD {
  min-width: 500px;
  display: flex;
  flex-direction: column;
  width: 50%;
  overflow: hidden;
  flex-grow: 1;
  color: rgb(217, 213, 212);
  padding-top: 5px;
  border: 1px solid #42424C;
  padding-right: 5px;
  background: #28292F;
}

.NodesPage-module__nodeResultWrapper__AbNw2 {
  height: 50%;
}

.NodesPage-module__nodeRunningJobInfoWrapper__p3_Vm {
  padding-left: 10px;
  padding-right: 10px;
  padding-top: 10px;
}

.NodesPage-module__refreshButtonWrapper__U0fnJ {
  display: flex;
  background-color: #28292F;
  align-self: center;
}

.NodesPage-module__nodeElementListWrapper__WXQUJ {
  padding: 14px 20px;
  background: #28292F;
  border: 1px solid var(--border-color);
  overflow: scroll;
  height: 100%;
}

.NodesPage-module__listWrapper__B7Ehq {
  flex-grow: 1;
  max-width: 100%;
  overflow-y: scroll;
}

.NodesPage-module__dot__IslHu {
  height: 5px;
  width: 5px;
  background-color: #bbb;
  border-radius: 50%;
  display: inline-block;
}
/*!***************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Nodes/components/NodeElement/NodeElement.module.scss ***!
  \***************************************************************************************************************************************************************************************/
.NodeElement-module__rowWrapper__YNMER {
  justify-content: space-between;
  font-style: normal;
  font-weight: 500;
  border: 2px solid var(--border-color);
  border-radius: 8px;
  margin-top: 6px;
  margin-bottom: 9px;
  position: relative;
  background-color: var(--popup-background);
  border-left-color: rgba(165, 172, 182, 0.4);
  padding: 10px 17px;
  min-height: 19px;
}

.NodeElement-module__nodeSelected__xxjO1 {
  border-left-color: #00D59A;
}

.NodeElement-module__row__de0rI {
  display: flex;
  justify-content: space-between;
  flex-direction: row;
  max-width: 100%;
}

.NodeElement-module__dot__qCmzl {
  min-height: 7px;
  min-width: 7px;
  background-color: rgba(165, 172, 182, 0.2);
  border-radius: 50%;
  display: inline-block;
  margin-top: 11px;
}

.NodeElement-module__dotSelected__SDRfn {
  background-color: #00D59A;
}

.NodeElement-module__runButton__L3pwk {
  cursor: pointer;
  padding: 5px 9px;
  background: #009380;
  border-radius: 16px;
}

.NodeElement-module__runButtonIcon__Y0zpG {
  width: 10px;
  height: 10px;
  margin-right: 4px;
}

.NodeElement-module__runButtonText__e3la5 {
  font-size: 12px;
  color: white;
}

.NodeElement-module__dotWrapper__owmuh {
  padding-right: 10px;
  padding-left: 10px;
  display: inline-flex;
  max-width: 80%;
}

.NodeElement-module__titleOrNameWrapper__r7Lxn {
  align-items: center;
  max-width: 80%;
  width: 20%;
  display: flex;
  flex: 1;
  font-size: 16px;
  font-weight: bolder;
}

.NodeElement-module__titleOrName__pHXwp {
  display: block;
  max-width: 100%;
}

.NodeElement-module__descriptionTooltip__ILMUC {
  overflow: scroll;
  max-height: 500px;
  white-space: pre-line;
  border-radius: 6px;
}

.NodeElement-module__descriptionWrapper__jJass {
  padding-left: 10px;
  align-content: center;
  text-align: right;
  margin-top: 5px;
}

.NodeElement-module__description__DUtJN {
  max-width: 100%;
}

.NodeElement-module__descriptionText__DF716 {
  font-size: 13px;
}

.NodeElement-module__updateAllButton__mUEOd {
  width: 80px;
}
/*!***************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/common/Parameters/Parameters.module.scss ***!
  \***************************************************************************************************************************************************************************/
.Parameters-module__parametersWrapper__xdyRD {
  gap: 10px;
  font-size: 12px;
  padding-left: 15px;
  padding-top: 10px;
}

.Parameters-module__arrowIconWrapper__PcyWL {
  margin-top: -3px;
  padding-right: 5px;
}

.Parameters-module__nodeNotSelected__UL1PR {
  display: none;
}

.Parameters-module__parameterTitle__u75Uq {
  font-size: 14px;
  height: 25px;
  display: flex;
}

.Parameters-module__parameterValues__jaXi6 {
  display: flex;
  width: 100%;
}

.Parameters-module__parameterLabel__HGE5T {
  padding: 10px 20px;
  align-content: center;
  text-wrap: nowrap;
}

.Parameters-module__parameterValue__ULkZq {
  width: 100%;
  margin-top: 2px;
  max-height: 25px;
}
.Parameters-module__parameterValue__ULkZq div, .Parameters-module__parameterValue__ULkZq input {
  height: 90%;
  color: var(--font) !important;
  border-color: var(--box-background) !important;
}
.Parameters-module__parameterValue__ULkZq span {
  padding: 0;
  align-self: center;
}
.Parameters-module__parameterValue__ULkZq fieldset {
  border-color: var(--box-background) !important;
}
/*!******************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/common/Error/ErrorStatusWrapper.module.scss ***!
  \******************************************************************************************************************************************************************************/
.ErrorStatusWrapper-module__statusErrorWrapper__yRd55 {
  overflow: scroll;
  max-height: 150px;
  padding: 20px;
  padding-top: 0;
  flex: none;
}

.ErrorStatusWrapper-module__statusErrorHeaderWrapper__Th6J0 {
  padding-left: 0;
  padding-top: 10px;
  padding-bottom: 5px;
  font-weight: bold;
}

.ErrorStatusWrapper-module__statusErrorRowWrapper__bD5G6 {
  overflow: scroll;
  padding-left: 0;
}
/*!*************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Nodes/components/RunningJob/RunningJob.module.scss ***!
  \*************************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.RunningJob-module__wrapper__Rx0kS {
  display: flex;
  flex-direction: column;
  max-height: 52%;
  color: #A5ACB6;
  padding-bottom: 28px;
}

.RunningJob-module__title__PAZOZ {
  display: flex;
  align-items: center;
  gap: 10px;
  font-size: 20px;
  vertical-align: middle;
}

.RunningJob-module__runningJobWrapper__jUmfb {
  display: inline-flex;
}

.RunningJob-module__runningJobNameWrapper__bQnDB {
  display: inline-flex;
}

.RunningJob-module__runningJobName__zWqCR {
  color: white;
}

.RunningJob-module__dot__uugRO {
  margin-right: 10px;
  height: 12px;
  width: 12px;
  background-color: limegreen;
  border-radius: 50%;
  display: inline-block;
}

.RunningJob-module__stopButtonContainer__vVgYn {
  display: flex;
  flex: 1;
  justify-content: flex-end;
  padding-right: 10px;
}

.RunningJob-module__stopButtonWrapper__YjZXJ {
  cursor: pointer;
}

.RunningJob-module__stopButton__ApZLM {
  background-color: #e02525;
}

.RunningJob-module__parameterStatesWrapper__IxzJf {
  display: flex;
  max-height: 220px;
}

.RunningJob-module__parameterColumnWrapper__A0lWZ {
  width: 50%;
  margin-top: 12px;
  padding-bottom: 3px;
  margin-right: 6px;
  background-color: var(--popup-background);
  border: 1px solid var(--border-color);
  border-radius: 4px;
  overflow: scroll;
}

.RunningJob-module__statesColumnWrapper__t9ZSc {
  width: 50%;
  margin-top: 12px;
  margin-left: 6px;
  background-color: var(--popup-background);
  border: 1px solid var(--border-color);
  border-radius: 4px;
  padding-bottom: 14px;
  padding-top: 6px;
}

.RunningJob-module__runInfoWrapper__qHehG {
  display: flex;
  padding-left: 20px;
  margin-top: 20px;
  padding-top: 6px;
  padding-bottom: 10px;
  font-size: 14px;
  background-color: var(--popup-background);
  border: 1px solid var(--border-color);
  border-radius: 4px;
}

.RunningJob-module__runInfoColumn__bGGYl {
  display: grid;
  width: 50%;
}

.RunningJob-module__jobInfoKey__XDXe1 {
  display: inline-flex;
  width: 100px;
}

.RunningJob-module__jobInfoKeySecondColumn___ARa2 {
  display: inline-flex;
  width: 50px;
}

.RunningJob-module__jobInfoValue__TR61j {
  display: inline-flex;
  color: white;
  word-break: break-all;
}

.RunningJob-module__jobInfoValueText__CMTUe {
  color: #A5ACB6;
}

.RunningJob-module__runInfoRow__IE9YW {
  display: inline-flex;
  padding-top: 7px;
}

.RunningJob-module__parametersWrapper__tjNf5 {
  padding-top: 6px;
  padding-left: 20px;
  max-height: 200px;
  overflow-y: scroll;
  padding-right: 10px;
  scrollbar-width: thin;
  scrollbar-color: #A5ACB6 transparent;
}

.RunningJob-module__parametersWrapper__tjNf5::-webkit-scrollbar {
  width: 2px;
}

.RunningJob-module__parametersWrapper__tjNf5::-webkit-scrollbar-track {
  background: transparent;
}

.RunningJob-module__parametersWrapper__tjNf5::-webkit-scrollbar-thumb {
  border-radius: 2px;
}

.RunningJob-module__parameterTitleWrapper__GOWPH {
  display: flex;
  font-size: 14px;
  padding: 5px 15px 5px 0;
}

.RunningJob-module__parameterValues__OFRLP {
  display: flex;
  width: 100%;
  font-size: 12px;
}

.RunningJob-module__parameterLabel__EgXsB {
  padding-right: 10px;
  padding-top: 10px;
  width: 100px;
  font-size: 12px;
}

.RunningJob-module__parameterValue__OiiZH {
  padding-top: 10px;
  color: white;
  font-size: 14px;
}

.RunningJob-module__stateWrapper__u73RL {
  display: flex;
  font-size: 14px;
  font-weight: bold;
  padding: 5px 15px 5px 20px;
}

.RunningJob-module__stateTitle__hlBQK {
  width: 100%;
  text-wrap-mode: nowrap;
}

.RunningJob-module__updateAllButton__dBFBk {
  font-family: Roboto, serif;
  height: 20px;
  text-wrap: nowrap;
  font-size: 14px;
  color: #3CDEF8 !important;
  text-transform: none !important;
}

.RunningJob-module__stateUpdatesTopWrapper__vHbLl {
  max-height: 170px;
  overflow-y: scroll;
  padding-right: 10px;
  scrollbar-width: thin;
  scrollbar-color: #A5ACB6 transparent;
  max-height: calc(100% - 51px);
  margin-bottom: 10px;
  margin-top: 6px;
}

.RunningJob-module__stateUpdatesTopWrapper__vHbLl::-webkit-scrollbar {
  width: 2px;
}

.RunningJob-module__stateUpdatesTopWrapper__vHbLl::-webkit-scrollbar-track {
  background: transparent;
}

.RunningJob-module__stateUpdatesTopWrapper__vHbLl::-webkit-scrollbar-thumb {
  border-radius: 2px;
}

.RunningJob-module__stateUpdateWrapper__xHz7R {
  padding-bottom: 5px;
  padding-left: 20px;
}

.RunningJob-module__stateUpdateOrderNumberAndTitleWrapper__DsmST {
  font-family: Roboto, serif;
  font-size: 12px;
  display: flex;
}

.RunningJob-module__stateUpdateOrderNumber__LxD1x {
  color: #A5ACB6;
}

.RunningJob-module__stateUpdateOrderKey__XT3AO {
  padding-left: 7px;
  color: white;
}

.RunningJob-module__stateUpdateValueWrapper__WxnTo {
  display: flex;
  padding-left: 12px;
  padding-top: 8px;
  padding-bottom: 16px;
  align-items: center;
  justify-content: space-between;
}

.RunningJob-module__stateUpdateValueOld__huRiI {
  display: flex;
  align-items: center;
}

.RunningJob-module__stateUpdateRightArrowIconWrapper__l9AOx {
  padding-left: 5px;
  padding-right: 5px;
  align-content: center;
}

.RunningJob-module__stateUpdateUndoIconWrapper__yC9y7 {
  padding-left: 12px;
  padding-top: 3px;
}
.RunningJob-module__stateUpdateUndoIconWrapper__yC9y7 svg {
  cursor: pointer;
}

.RunningJob-module__stateUpdateValueNew__pncWz {
  display: flex;
  align-items: center;
}

.RunningJob-module__valueContainer__GUxeP {
  display: inline-block;
  padding: 2px 4px;
  font-size: 14px;
  background-color: #42464C;
  color: white;
  border-radius: 6px;
  border: 1px solid #42464C;
  transition: all 1s ease;
  cursor: pointer;
  width: fit-content;
  max-width: 100%;
  height: fit-content;
  align-items: center;
  outline: none !important;
}

.RunningJob-module__valueContainerHovered__RS5CA {
  display: inline-block;
  padding: 2px 4px;
  font-size: 14px;
  background-color: rgba(44, 203, 229, 0.1);
  color: #3CDEF8;
  border-radius: 6px;
  border: 1px solid rgba(44, 203, 229, 0.1);
  cursor: pointer;
}

.RunningJob-module__valueContainerEditable__rtt7H {
  display: inline-block;
  padding: 2px 4px;
  font-size: 14px;
  color: #3CDEF8;
  border-radius: 6px;
  cursor: pointer;
  border: 1px solid rgba(44, 203, 229, 0.1);
  background: rgba(44, 203, 229, 0.1);
}

.RunningJob-module__valueContainerDisabled__QV4Oo {
  display: inline-block;
  padding: 2px 4px;
  font-size: 14px;
  color: #32FFC6;
  border-radius: 6px;
  border: 1px solid rgba(0, 213, 154, 0.1);
  background: rgba(0, 213, 154, 0.1);
}

input:focus {
  outline: none !important;
}

.RunningJob-module__stateUpdateIconBeforeWrapper__yEt6m {
  margin-left: auto;
  padding-right: 13px;
  display: flex;
  align-items: center;
}
.RunningJob-module__stateUpdateIconBeforeWrapper__yEt6m svg {
  cursor: pointer;
}

.RunningJob-module__stateUpdateIconAfterWrapper__gJFxv {
  margin-left: auto;
  padding-right: 13px;
  display: flex;
  align-items: center;
}

.RunningJob-module__stateUpdateComponentTextWrapper__sV573 {
  padding-left: 10px;
}

.RunningJob-module__stateUpdateKeyText__EpMtg {
  font-weight: bold;
}

.RunningJob-module__upArrowIconWrapper__rWEfb {
  cursor: pointer;
}

.RunningJob-module__stateUpdateValueText__h_j1J {
  font-size: 12px;
}

.RunningJob-module__stateUpdateValueTextWrapper__Olrca {
  padding-top: 5px;
  align-items: center;
  display: flex;
}

.RunningJob-module__editIconWrapper__SXX1t {
  padding-left: 5px;
}

.RunningJob-module__newValueOfState__CALVy {
  padding-left: 5px;
}
.RunningJob-module__newValueOfState__CALVy input {
  font-size: 12px;
  padding: 0 !important;
  height: 20px !important;
}
/*!********************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/common/ToggleSwitch/ToggleSwitch.module.scss ***!
  \********************************************************************************************************************************************************************************************/
.ToggleSwitch-module__firstRowWrapper__ddNIp {
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.ToggleSwitch-module__switchWrapper__cdXyg {
  display: flex;
  gap: 8px;
  padding: 4px;
  border-radius: 31px;
  border: 1px solid var(--border, #42424C);
}

.ToggleSwitch-module__switchOption__yV48A {
  padding: 6px 12px;
  border-radius: 16px;
  cursor: pointer;
  transition: background 0.3s ease;
  color: #b0b0b0;
}

.ToggleSwitch-module__active__fcsjO {
  background: rgba(44, 203, 229, 0.6);
  color: white;
}
/*!********************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/common/Iframe/Iframe.module.scss ***!
  \********************************************************************************************************************************************************************************/
.Iframe-module__notLoaded__TUFH7 {
  background: black;
  width: 100%;
  height: 100%;
}

.Iframe-module__iframe__S5B5G {
  width: 100%;
  height: 100%;
}
/*!*******************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Nodes/components/Results/Results.module.scss ***!
  \*******************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.Results-module__wrapper__sKx7z {
  height: 100%;
  border: 1px solid var(--border-color);
  background-color: var(--popup-background);
  padding-bottom: 15px;
  flex: 1;
  overflow-y: auto;
}

.Results-module__errorWrapper__XLiwi {
  height: 100%;
  border: 2px solid rgba(255, 97, 115, 0.5);
  background-color: var(--popup-background);
  padding-bottom: 15px;
  flex: 1;
  overflow-y: auto;
}

.Results-module__errorHeader__aRVrV {
  padding-top: 30px;
  padding-left: 30px;
  display: flex;
  flex-direction: row;
}

.Results-module__errorIcon__hK3Pi {
  display: flex;
  align-items: center;
}

.Results-module__errorHeaderTitle__TE7hP {
  padding-left: 9px;
  color: #FF6173;
  font-family: Roboto, serif;
  font-size: 20px;
  font-style: normal;
  font-weight: 400;
  line-height: normal;
}

.Results-module__errorContent__XXs4c {
  padding-left: 30px;
}

.Results-module__errorLabel__coIDp {
  padding-top: 25px;
  padding-bottom: 8px;
  color: #A5ACB6;
  font-family: Roboto, serif;
  font-size: 12px;
  font-style: normal;
  font-weight: 400;
  line-height: normal;
}

.Results-module__errorText___F4rj {
  color: #FFF;
  font-family: Roboto, serif;
  font-size: 12px;
  font-style: normal;
  line-height: 150%;
}
/*!************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/GraphLibrary.module.scss ***!
  \************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.GraphLibrary-module__wrapper__ItO_H {
  height: 100%;
  display: flex;
  color: var(--font) !important;
}

.GraphLibrary-module__nodesContainer__a8z2I {
  display: flex;
  flex-direction: column;
  overflow: hidden;
  flex-grow: 1;
  margin-left: 20px;
  margin-right: 20px;
  margin-bottom: 10px;
  border-radius: var(--border-radius);
}

.GraphLibrary-module__refreshButtonWrapper__v76H6 {
  justify-content: space-between;
}

.GraphLibrary-module__searchAndRefresh__wsmuK {
  display: flex;
  gap: 30px;
  padding-bottom: 10px;
}

.GraphLibrary-module__buttonWrapper__Ifi_u {
  align-content: center;
}

.GraphLibrary-module__listWrapper__eVjIB {
  flex-grow: 1;
  border: 2px solid var(--border-color);
  padding: 2px;
  background-color: var(--popup-background);
  max-width: 100%;
  overflow: scroll;
}
/*!************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphElement/GraphElement.module.scss ***!
  \************************************************************************************************************************************************************************************************/
.GraphElement-module__searchContainer__j6k9P {
  max-width: 280px;
  padding-bottom: 20px;
}
.GraphElement-module__searchContainer__j6k9P input {
  border-radius: 25px;
  font-style: italic;
}

.GraphElement-module__wrapper__qOVme {
  padding-top: 13px;
  padding-left: 25px;
  padding-bottom: 13px;
  width: auto;
  min-height: 30px;
  border: solid 1px var(--border-color);
  border-radius: 7px;
  flex-direction: column;
}

.GraphElement-module__upperContainer__MRzQz {
  display: flex;
}

.GraphElement-module__bottomContainer__GlV9O {
  display: flex;
}

.GraphElement-module__parametersContainer__SUp7f {
  max-width: 40%;
}

.GraphElement-module__graphContainer__ptHzy {
  flex: 1;
  align-content: center;
  width: 60%;
  padding-top: 10px;
  min-height: 300px;
}
.GraphElement-module__graphContainer__ptHzy.GraphElement-module__graphContainerVisible__IwuxI {
  min-height: 300px;
}

.GraphElement-module__leftContainer__aGHZ_ {
  place-content: center space-between;
  align-items: center;
  display: flex;
  gap: 10px;
  text-wrap: nowrap;
  width: 300px;
}

.GraphElement-module__rightContainer__X3Y1k {
  align-content: center;
  text-align: right;
  flex-grow: 1;
  padding-right: 10px;
}

.GraphElement-module__runButtonWrapper__x5rQN {
  align-content: center;
  max-height: fit-content;
  padding-right: 10px;
}
.GraphElement-module__runButtonWrapper__x5rQN svg {
  display: table-row;
}

.GraphElement-module__refreshButtonWrapper__adcD0 {
  align-content: center;
  color: var(--blue-icon-button-text);
}

.GraphElement-module__calibrationGraphSelected__Y8zk5 {
  background-color: var(--selected-node);
}
/*!****************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/CytoscapeGraph/CytoscapeGraph.module.scss ***!
  \****************************************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.CytoscapeGraph-module__wrapper__AWFuj {
  min-height: 20%;
  background: var(--background-color);
  border-radius: var(--border-radius);
  margin-left: 10px;
  margin-right: 10px;
  height: 100%;
}
/*!************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphElementErrorWrapper/GraphElementErrorWrapper.module.scss ***!
  \************************************************************************************************************************************************************************************************************************/
.GraphElementErrorWrapper-module__wrapper__zW6Fl {
  gap: 10px;
  font-size: 12px;
  padding-left: 15px;
  padding-top: 10px;
}

.GraphElementErrorWrapper-module__titleAndIconWrapper__zodjS {
  display: flex;
  font-size: 14px;
}

.GraphElementErrorWrapper-module__arrowIconWrapper__UFVKR {
  margin-top: -3px;
  padding-right: 5px;
}

.GraphElementErrorWrapper-module__errorObjectWrapper__RIEgU {
  padding: 10px 20px;
  align-content: center;
  overflow-wrap: anywhere;
}
/*!**********************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphStatus/GraphStatus.module.scss ***!
  \**********************************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.GraphStatus-module__wrapper__kCclg {
  height: calc(100% - 5px);
  width: 100%;
  display: flex;
  background: var(--background-color);
  border-radius: var(--border-radius);
}

.GraphStatus-module__graphContainer__UZgHc {
  flex: 1;
  align-content: center;
  width: 60%;
}

.GraphStatus-module__graphAndHistoryWrapper__xS94z {
  height: 100%;
  width: 100%;
  display: flex;
  flex-direction: column;
}

.GraphStatus-module__leftContainer__GyxFy {
  display: flex;
  color: rgb(217, 213, 212);
  min-width: 33%;
  height: 100%;
}

.GraphStatus-module__rightContainer__EXZ8p {
  display: flex;
  flex-direction: column;
  width: 50%;
  overflow: hidden;
  flex-grow: 1;
  color: rgb(217, 213, 212);
  margin-left: 20px;
  margin-right: 20px;
  height: 100%;
  background-color: var(--background-color);
}
/*!***********************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphStatus/components/MeasurementHistory/MeasurementHistory.module.scss ***!
  \***********************************************************************************************************************************************************************************************************************************/
.MeasurementHistory-module__wrapper__mYNes {
  font-style: normal;
  font-weight: 500;
  height: 50%;
}

.MeasurementHistory-module__titleRow__EPgcN {
  display: flex;
  align-items: center;
  background-color: var(--popup-background);
  padding: 8px 12px;
  font-size: 16px;
  justify-content: space-between;
}

.MeasurementHistory-module__title__nO7yq {
  color: #fff;
  font-family: "Roboto Condensed", serif;
  font-size: 18px;
  font-weight: 500;
}

.MeasurementHistory-module__trackLatestWrapper__WJM3w {
  display: flex;
  align-items: center;
  color: #c6cdd6;
  font-family: Roboto, serif;
  font-size: 14px;
  font-weight: 400;
  gap: 8px;
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w span {
  font-size: 14px;
  color: #fff;
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w .MeasurementHistory-module__toggleSwitch__MpExc {
  width: 36px;
  height: 12px;
  background-color: #4a4a4a;
  border-radius: 6px;
  position: relative;
  cursor: pointer;
  transition: background-color 0.3s ease;
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w .MeasurementHistory-module__toggleSwitch__MpExc.MeasurementHistory-module__toggleOn__jpZkx {
  background-color: #28a745;
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w .MeasurementHistory-module__toggleSwitch__MpExc.MeasurementHistory-module__toggleOff__CO_Va {
  background-color: #4a4a4a;
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w .MeasurementHistory-module__toggleKnob__gIY49 {
  width: 18px;
  height: 18px;
  background-color: #fff;
  border-radius: 50%;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -3px;
  left: 0;
  transition: left 0.3s ease;
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w .MeasurementHistory-module__toggleKnob__gIY49.MeasurementHistory-module__toggleOn__jpZkx {
  left: calc(100% - 18px);
}
.MeasurementHistory-module__trackLatestWrapper__WJM3w .MeasurementHistory-module__toggleKnob__gIY49.MeasurementHistory-module__toggleOff__CO_Va {
  left: 0;
}

.MeasurementHistory-module__contentContainer__pGUsz {
  background-color: #2A2B31;
  padding: 10px 12px;
  height: calc(100% - 60px);
}

.MeasurementHistory-module__lowerContainer__UVsJR {
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 14px;
  color: #c6cdd6;
  padding: 5px 0;
}
/*!*******************************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphStatus/components/MeasurementElementList/MeasurementElementList.module.scss ***!
  \*******************************************************************************************************************************************************************************************************************************************/
.MeasurementElementList-module__wrapper__okDtx {
  height: calc(100% - 11px);
  background-color: var(--background-color);
  padding: 10px;
  border: 1px solid var(--border-color);
  overflow: auto;
}
/*!*********************************************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/GraphLibrary/components/GraphStatus/components/MeasurementElementGraph/MeasurementElementGraph.module.scss ***!
  \*********************************************************************************************************************************************************************************************************************************************/
.MeasurementElementGraph-module__calibrationTitle__SHb6M {
  display: flex;
  align-items: center;
  font-size: 16px;
  color: var(--text-muted);
  margin-bottom: 8px;
}

.MeasurementElementGraph-module__dot__zbKv2 {
  width: 10px;
  height: 10px;
  border-radius: 50%;
  background-color: #40a8f5; /* Default Blue */
  margin-right: 8px;
  margin-left: 2px;
}

.MeasurementElementGraph-module__defaultBlue__gCie0 {
  background-color: #40a8f5 !important;
}

.MeasurementElementGraph-module__blinkingYellow__x5QIL {
  animation: MeasurementElementGraph-module__blink-animation__ThI8J 1s infinite alternate;
  background-color: #FC0 !important;
}

.MeasurementElementGraph-module__solidGreen__lpgcp {
  background-color: #00d59a !important;
}

@keyframes MeasurementElementGraph-module__blink-animation__ThI8J {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0.2;
  }
}
.MeasurementElementGraph-module__wrapper__W15d8 {
  padding-bottom: 10px;
  height: 50%;
  display: flex;
  flex-direction: column;
}

.MeasurementElementGraph-module__insideWrapper__ANkEr {
  flex: 1;
  max-height: 100%;
  justify-content: space-between;
  font-style: normal;
  font-weight: 500;
  border-radius: 7px;
  padding: 10px;
  margin-top: 2px;
  margin-bottom: 2px;
  border: 1px solid var(--border-color);
  background-color: var(--popup-background);
  overflow-y: auto;
}

.MeasurementElementGraph-module__lowerContainer__m6NGV {
  display: flex;
  flex-direction: column;
  height: 100%;
  gap: 10px;
}

.MeasurementElementGraph-module__lowerUpperContainer__s3GZy {
  display: flex;
  width: 100%;
  height: auto;
  min-height: 20%;
  padding-bottom: 10px;
}

.MeasurementElementGraph-module__label__PU13K {
  font-size: 16px;
  color: var(--text-muted);
  margin-right: 6px;
}

.MeasurementElementGraph-module__tuneUpName__HrV0k {
  font-size: 16px;
  color: #fff;
}

.MeasurementElementGraph-module__lowerUpperLeftContainer__EUy_F {
  min-width: 50%;
  padding-left: 10px;
  overflow-y: auto;
}

.MeasurementElementGraph-module__lowerUpperRightContainer__pscOp {
  width: 50%;
  display: flex;
  flex: 1;
  justify-content: flex-end;
  align-items: center;
  padding-right: 10px;
}

.MeasurementElementGraph-module__lowerLowerContainer__ttlrC {
  flex: 1;
  display: flex;
  flex-direction: column;
  width: 100%;
}
/*!********************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Data/Data.module.scss ***!
  \********************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.Data-module__wrapper__Hin_9 {
  display: flex;
  height: 100%;
}

.Data-module__dataWrapper__V8s4k {
  min-width: 350px;
  width: 30%;
  max-width: 800px;
  display: flex;
  flex-direction: column;
  height: 100%;
}

.Data-module__data__Ki7gp {
  overflow: scroll;
  height: 100%;
}

.Data-module__explorer__PKrch {
  height: 100%;
  width: 100%;
  display: flex;
  box-sizing: border-box;
}

.Data-module__viewer__gUTnu {
  display: flex;
  flex-grow: 1;
  border: 1px solid var(--border-color);
  overflow: hidden;
  width: 100%;
}
/*!***************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Pagination/PaginationWrapper.module.scss ***!
  \***************************************************************************************************************************************************************************/
.PaginationWrapper-module__wrapper__bt1TK {
  font-family: var(--font-family), serif;
  font-style: normal;
  font-weight: 400;
  font-size: 12px;
  line-height: 14px;
  display: flex;
  text-align: center;
  align-self: center;
  justify-content: center;
}
.PaginationWrapper-module__wrapper__bt1TK button,
.PaginationWrapper-module__wrapper__bt1TK div {
  color: var(--grey);
}
.PaginationWrapper-module__wrapper__bt1TK svg {
  color: #2ccbe5;
}
/*!**********************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Data/components/SnapshotElement/SnapshotElement.module.scss ***!
  \**********************************************************************************************************************************************************************************************/
.SnapshotElement-module__wrapper__QOEnq {
  display: flex;
  flex-direction: column;
  border: 1px solid var(--border-color);
  border-radius: 8px;
  margin: 0.5px 0;
  padding: 6px;
}

.SnapshotElement-module__headerWrapper__P5hv9 {
  padding-top: 10px;
  padding-bottom: 7px;
  display: flex;
  align-items: center;
  cursor: pointer;
}

.SnapshotElement-module__titleWrapper__iaBqJ {
  padding-left: 10px;
  padding-right: 3px;
}

.SnapshotElement-module__idWrapper__QECOp {
  color: #C6CDD6;
  font-size: 16px;
  font-weight: 400;
  line-height: normal;
  padding-right: 8px;
}

.SnapshotElement-module__nameWrapper__d2fD_ {
  color: #FFF;
  font-family: Roboto, serif;
  font-size: 16px;
  font-style: normal;
  font-weight: 500;
  line-height: normal;
}

.SnapshotElement-module__additionalWidth__ORhLG {
  min-width: 240px;
}
/*!**************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Data/components/SnapshotsTimeline/SnapshotsTimeline.module.scss ***!
  \**************************************************************************************************************************************************************************************************/
.SnapshotsTimeline-module__wrapper__sL82E {
  display: block;
}
/*!**************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/SidebarMenu/styles/MenuItem.module.scss ***!
  \**************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.MenuItem-module__itemWrapper__BDl71 {
  display: flex;
  align-items: center;
  gap: 20px;
  height: 45px;
  width: 100%;
  box-sizing: border-box;
  white-space: pre;
  padding-left: 24px !important;
  border-right: 2px solid transparent;
  font-size: 18px;
  color: var(--menu-text-color);
}
.MenuItem-module__itemWrapper__BDl71:hover {
  background-color: var(--menu-hover-text);
  border-right: 2px solid var(--menu-accent-color);
}
.MenuItem-module__itemWrapper__BDl71 svg {
  height: 24px;
  width: 24px;
  min-width: 24px;
}
/*!*****************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/SidebarMenu/styles/SidebarMenu.module.scss ***!
  \*****************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.SidebarMenu-module__container__DLYU8 {
  position: relative;
  width: 68px;
  height: 100vh;
}

.SidebarMenu-module__sidebarMenu__Bdo5Y {
  top: 0;
  left: 0;
  width: 68px;
  height: 100vh;
  box-sizing: border-box;
  padding-top: 24px;
  z-index: 10;
  display: flex;
  flex-direction: column;
  align-items: start;
  justify-content: space-between;
  background: var(--menu-background);
  transition: width ease-in-out 0.1s;
}
.SidebarMenu-module__sidebarMenu__Bdo5Y.SidebarMenu-module__opened__tLGgl {
  width: 198px;
}

.SidebarMenu-module__collapsed__FTHWa {
  width: 70px;
}

.SidebarMenu-module__expanded__gsiHX {
  width: 200px;
}

.SidebarMenu-module__qualibrateLogo__EXsI6 {
  padding-left: 24px;
  height: 50px;
  margin-bottom: 50px;
}
@media screen and (height <= 700px) {
  .SidebarMenu-module__qualibrateLogo__EXsI6 {
    margin-bottom: 10px;
  }
}

.SidebarMenu-module__menuContent__ouCvs {
  overflow-y: auto;
  flex: 1;
  width: 100%;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
}
.SidebarMenu-module__menuContent__ouCvs::-webkit-scrollbar {
  width: 8px;
  height: 8px;
}
.SidebarMenu-module__menuContent__ouCvs::-webkit-scrollbar-track {
  background: var(--background-color);
  width: 8px;
  box-shadow: inset 0 0 5px transparent;
}
.SidebarMenu-module__menuContent__ouCvs::-webkit-scrollbar-thumb {
  background: var(--popup-background);
  width: 4px;
  border-radius: 10px;
}

.SidebarMenu-module__menuBottomContent__tygxG,
.SidebarMenu-module__menuUpperContent__lQSFd {
  display: flex;
  flex-direction: column;
}
.SidebarMenu-module__menuBottomContent__tygxG > * + *,
.SidebarMenu-module__menuUpperContent__lQSFd > * + * {
  margin-top: 15px;
}

.SidebarMenu-module__themeToggleContainer__sHojT {
  margin-top: auto;
  margin-bottom: 10px;
}
/*!*********************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[4].use[2]!./node_modules/prismjs/themes/prism.css ***!
  \*********************************************************************************************************************/
/**
 * prism.js default theme for JavaScript, CSS and HTML
 * Based on dabblet (http://dabblet.com)
 * @author Lea Verou
 */

code[class*="language-"],
pre[class*="language-"] {
	color: black;
	background: none;
	text-shadow: 0 1px white;
	font-family: Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace;
	font-size: 1em;
	text-align: left;
	white-space: pre;
	word-spacing: normal;
	word-break: normal;
	word-wrap: normal;
	line-height: 1.5;

	-moz-tab-size: 4;
	-o-tab-size: 4;
	tab-size: 4;

	-webkit-hyphens: none;
	-moz-hyphens: none;
	-ms-hyphens: none;
	hyphens: none;
}

pre[class*="language-"]::-moz-selection, pre[class*="language-"] ::-moz-selection,
code[class*="language-"]::-moz-selection, code[class*="language-"] ::-moz-selection {
	text-shadow: none;
	background: #b3d4fc;
}

pre[class*="language-"]::selection, pre[class*="language-"] ::selection,
code[class*="language-"]::selection, code[class*="language-"] ::selection {
	text-shadow: none;
	background: #b3d4fc;
}

@media print {
	code[class*="language-"],
	pre[class*="language-"] {
		text-shadow: none;
	}
}

/* Code blocks */
pre[class*="language-"] {
	padding: 1em;
	margin: .5em 0;
	overflow: auto;
}

:not(pre) > code[class*="language-"],
pre[class*="language-"] {
	background: #f5f2f0;
}

/* Inline code */
:not(pre) > code[class*="language-"] {
	padding: .1em;
	border-radius: .3em;
	white-space: normal;
}

.token.comment,
.token.prolog,
.token.doctype,
.token.cdata {
	color: slategray;
}

.token.punctuation {
	color: #999;
}

.token.namespace {
	opacity: .7;
}

.token.property,
.token.tag,
.token.boolean,
.token.number,
.token.constant,
.token.symbol,
.token.deleted {
	color: #905;
}

.token.selector,
.token.attr-name,
.token.string,
.token.char,
.token.builtin,
.token.inserted {
	color: #690;
}

.token.operator,
.token.entity,
.token.url,
.language-css .token.string,
.style .token.string {
	color: #9a6e3a;
	/* This background color was intended by the author of this theme. */
	background: hsla(0, 0%, 100%, .5);
}

.token.atrule,
.token.attr-value,
.token.keyword {
	color: #07a;
}

.token.function,
.token.class-name {
	color: #DD4A68;
}

.token.regex,
.token.important,
.token.variable {
	color: #e90;
}

.token.important,
.token.bold {
	font-weight: bold;
}
.token.italic {
	font-style: italic;
}

.token.entity {
	cursor: help;
}

/*!********************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[4].use[2]!./node_modules/prism-color-variables/variables.css ***!
  \********************************************************************************************************************************/
.token.comment,
.token.block-comment {
    color: var(--code-highlight-comment-color, #708090);
}

.token.prolog {
    color: var(--code-highlight-prolog-color, #708090);
}

.token.doctype {
    color: var(--code-highlight-doctype-color, #708090);
}

.token.cdata {
    color: var(--code-highlight-cdata-color, #708090);
}

.token.tag {
    color: var(--code-highlight-tag-color, #905);
}

.token.entity {
    color: var(--code-highlight-entity-color, #9a6e3a);
}

.token.atrule {
    color: var(--code-highlight-atrule-color, #07a);
}

.token.url {
    color: var(--code-highlight-url-color, #9a6e3a);
}

.token.selector {
    color: var(--code-highlight-selector-color, #690);
}

.token.string {
    color: var(--code-highlight-string-color, #690);
}

.token.property {
    color: var(--code-highlight-property-color, #905);
}

.token.important {
    color: var(--code-highlight-important-color, #e90);
}

.token.punctuation {
    color: var(--code-highlight-punctuation-color, #999);
}

.token.number {
    color: var(--code-highlight-number-color, #905);
}

.token.function {
    color: var(--code-highlight-function-color, #dd4a68);
}

.token.class-name {
    color: var(--code-highlight-class-name-color, #dd4a68);
}

.token.keyword {
    color: var(--code-highlight-keyword-color, #07a);
}

.token.boolean {
    color: var(--code-highlight-boolean-color, #905);
}

.token.operator {
    color: var(--code-highlight-operator-color, #9a6e3a);
}

.token.char {
    color: var(--code-highlight-char-color, #690);
}

.token.regex {
    color: var(--code-highlight-regex-color, #e90);
}

.token.variable {
    color: var(--code-highlight-variable-color, #e90);
}

.token.constant {
    color: var(--code-highlight-constant-color, #905);
}

.token.symbol {
    color: var(--code-highlight-symbol-color, #905);
}

.token.function-name {
    color: var(--code-highlight-function-name-color, #905);
}

.token.builtin {
    color: var(--code-highlight-builtin-color, #690);
}

.token.attr-name {
    color: var(--code-highlight-attr-2f9c0a-color, #690);
}

.token.attr-value {
    color: var(--code-highlight-attr-value-color, #07a);
}

.token.inserted {
    color: var(--code-highlight-inserted-color, #690);
}

.token.deleted {
    color: var(--code-highlight-deleted-color, #905);
}

.token.namespace {
    color: var(--code-highlight-namespace-color, #708090);
}

.token.bold {
    font-weight: bold;
}

.token.italic {
    font-style: italic;
}

/*!**********************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[4].use[2]!./node_modules/react-toastify/dist/ReactToastify.css ***!
  \**********************************************************************************************************************************/
:root {
  --toastify-color-light: #fff;
  --toastify-color-dark: #121212;
  --toastify-color-info: #3498db;
  --toastify-color-success: #07bc0c;
  --toastify-color-warning: #f1c40f;
  --toastify-color-error: #e74c3c;
  --toastify-color-transparent: rgba(255, 255, 255, 0.7);
  --toastify-icon-color-info: var(--toastify-color-info);
  --toastify-icon-color-success: var(--toastify-color-success);
  --toastify-icon-color-warning: var(--toastify-color-warning);
  --toastify-icon-color-error: var(--toastify-color-error);
  --toastify-toast-width: 320px;
  --toastify-toast-offset: 16px;
  --toastify-toast-top: max(var(--toastify-toast-offset), env(safe-area-inset-top));
  --toastify-toast-right: max(var(--toastify-toast-offset), env(safe-area-inset-right));
  --toastify-toast-left: max(var(--toastify-toast-offset), env(safe-area-inset-left));
  --toastify-toast-bottom: max(var(--toastify-toast-offset), env(safe-area-inset-bottom));
  --toastify-toast-background: #fff;
  --toastify-toast-min-height: 64px;
  --toastify-toast-max-height: 800px;
  --toastify-toast-bd-radius: 6px;
  --toastify-font-family: sans-serif;
  --toastify-z-index: 9999;
  --toastify-text-color-light: #757575;
  --toastify-text-color-dark: #fff;
  --toastify-text-color-info: #fff;
  --toastify-text-color-success: #fff;
  --toastify-text-color-warning: #fff;
  --toastify-text-color-error: #fff;
  --toastify-spinner-color: #616161;
  --toastify-spinner-color-empty-area: #e0e0e0;
  --toastify-color-progress-light: linear-gradient(
    to right,
    #4cd964,
    #5ac8fa,
    #007aff,
    #34aadc,
    #5856d6,
    #ff2d55
  );
  --toastify-color-progress-dark: #bb86fc;
  --toastify-color-progress-info: var(--toastify-color-info);
  --toastify-color-progress-success: var(--toastify-color-success);
  --toastify-color-progress-warning: var(--toastify-color-warning);
  --toastify-color-progress-error: var(--toastify-color-error);
  --toastify-color-progress-bgo: 0.2;
}

.Toastify__toast-container {
  z-index: var(--toastify-z-index);
  -webkit-transform: translate3d(0, 0, var(--toastify-z-index));
  position: fixed;
  padding: 4px;
  width: var(--toastify-toast-width);
  box-sizing: border-box;
  color: #fff;
}
.Toastify__toast-container--top-left {
  top: var(--toastify-toast-top);
  left: var(--toastify-toast-left);
}
.Toastify__toast-container--top-center {
  top: var(--toastify-toast-top);
  left: 50%;
  transform: translateX(-50%);
}
.Toastify__toast-container--top-right {
  top: var(--toastify-toast-top);
  right: var(--toastify-toast-right);
}
.Toastify__toast-container--bottom-left {
  bottom: var(--toastify-toast-bottom);
  left: var(--toastify-toast-left);
}
.Toastify__toast-container--bottom-center {
  bottom: var(--toastify-toast-bottom);
  left: 50%;
  transform: translateX(-50%);
}
.Toastify__toast-container--bottom-right {
  bottom: var(--toastify-toast-bottom);
  right: var(--toastify-toast-right);
}

@media only screen and (max-width : 480px) {
  .Toastify__toast-container {
    width: 100vw;
    padding: 0;
    left: env(safe-area-inset-left);
    margin: 0;
  }
  .Toastify__toast-container--top-left, .Toastify__toast-container--top-center, .Toastify__toast-container--top-right {
    top: env(safe-area-inset-top);
    transform: translateX(0);
  }
  .Toastify__toast-container--bottom-left, .Toastify__toast-container--bottom-center, .Toastify__toast-container--bottom-right {
    bottom: env(safe-area-inset-bottom);
    transform: translateX(0);
  }
  .Toastify__toast-container--rtl {
    right: env(safe-area-inset-right);
    left: initial;
  }
}
.Toastify__toast {
  --y: 0;
  position: relative;
  -ms-touch-action: none;
      touch-action: none;
  min-height: var(--toastify-toast-min-height);
  box-sizing: border-box;
  margin-bottom: 1rem;
  padding: 8px;
  border-radius: var(--toastify-toast-bd-radius);
  box-shadow: 0px 4px 12px rgba(0, 0, 0, 0.1);
  display: -ms-flexbox;
  display: flex;
  -ms-flex-pack: justify;
      justify-content: space-between;
  max-height: var(--toastify-toast-max-height);
  font-family: var(--toastify-font-family);
  cursor: default;
  direction: ltr;
  /* webkit only issue #791 */
  z-index: 0;
  overflow: hidden;
}
.Toastify__toast--stacked {
  position: absolute;
  width: 100%;
  transform: translate3d(0, var(--y), 0) scale(var(--s));
  transition: transform 0.3s;
}
.Toastify__toast--stacked[data-collapsed] .Toastify__toast-body, .Toastify__toast--stacked[data-collapsed] .Toastify__close-button {
  transition: opacity 0.1s;
}
.Toastify__toast--stacked[data-collapsed=false] {
  overflow: visible;
}
.Toastify__toast--stacked[data-collapsed=true]:not(:last-child) > * {
  opacity: 0;
}
.Toastify__toast--stacked:after {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  height: calc(var(--g) * 1px);
  bottom: 100%;
}
.Toastify__toast--stacked[data-pos=top] {
  top: 0;
}
.Toastify__toast--stacked[data-pos=bot] {
  bottom: 0;
}
.Toastify__toast--stacked[data-pos=bot].Toastify__toast--stacked:before {
  transform-origin: top;
}
.Toastify__toast--stacked[data-pos=top].Toastify__toast--stacked:before {
  transform-origin: bottom;
}
.Toastify__toast--stacked:before {
  content: "";
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
  height: 100%;
  transform: scaleY(3);
  z-index: -1;
}
.Toastify__toast--rtl {
  direction: rtl;
}
.Toastify__toast--close-on-click {
  cursor: pointer;
}
.Toastify__toast-body {
  margin: auto 0;
  -ms-flex: 1 1 auto;
      flex: 1 1 auto;
  padding: 6px;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-align: center;
      align-items: center;
}
.Toastify__toast-body > div:last-child {
  word-break: break-word;
  -ms-flex: 1;
      flex: 1;
}
.Toastify__toast-icon {
  -webkit-margin-end: 10px;
          margin-inline-end: 10px;
  width: 20px;
  -ms-flex-negative: 0;
      flex-shrink: 0;
  display: -ms-flexbox;
  display: flex;
}

.Toastify--animate {
  animation-fill-mode: both;
  animation-duration: 0.5s;
}

.Toastify--animate-icon {
  animation-fill-mode: both;
  animation-duration: 0.3s;
}

@media only screen and (max-width : 480px) {
  .Toastify__toast {
    margin-bottom: 0;
    border-radius: 0;
  }
}
.Toastify__toast-theme--dark {
  background: var(--toastify-color-dark);
  color: var(--toastify-text-color-dark);
}
.Toastify__toast-theme--light {
  background: var(--toastify-color-light);
  color: var(--toastify-text-color-light);
}
.Toastify__toast-theme--colored.Toastify__toast--default {
  background: var(--toastify-color-light);
  color: var(--toastify-text-color-light);
}
.Toastify__toast-theme--colored.Toastify__toast--info {
  color: var(--toastify-text-color-info);
  background: var(--toastify-color-info);
}
.Toastify__toast-theme--colored.Toastify__toast--success {
  color: var(--toastify-text-color-success);
  background: var(--toastify-color-success);
}
.Toastify__toast-theme--colored.Toastify__toast--warning {
  color: var(--toastify-text-color-warning);
  background: var(--toastify-color-warning);
}
.Toastify__toast-theme--colored.Toastify__toast--error {
  color: var(--toastify-text-color-error);
  background: var(--toastify-color-error);
}

.Toastify__progress-bar-theme--light {
  background: var(--toastify-color-progress-light);
}
.Toastify__progress-bar-theme--dark {
  background: var(--toastify-color-progress-dark);
}
.Toastify__progress-bar--info {
  background: var(--toastify-color-progress-info);
}
.Toastify__progress-bar--success {
  background: var(--toastify-color-progress-success);
}
.Toastify__progress-bar--warning {
  background: var(--toastify-color-progress-warning);
}
.Toastify__progress-bar--error {
  background: var(--toastify-color-progress-error);
}
.Toastify__progress-bar-theme--colored.Toastify__progress-bar--info, .Toastify__progress-bar-theme--colored.Toastify__progress-bar--success, .Toastify__progress-bar-theme--colored.Toastify__progress-bar--warning, .Toastify__progress-bar-theme--colored.Toastify__progress-bar--error {
  background: var(--toastify-color-transparent);
}

.Toastify__close-button {
  color: #fff;
  background: transparent;
  outline: none;
  border: none;
  padding: 0;
  cursor: pointer;
  opacity: 0.7;
  transition: 0.3s ease;
  -ms-flex-item-align: start;
      align-self: flex-start;
  z-index: 1;
}
.Toastify__close-button--light {
  color: #000;
  opacity: 0.3;
}
.Toastify__close-button > svg {
  fill: currentColor;
  height: 16px;
  width: 14px;
}
.Toastify__close-button:hover, .Toastify__close-button:focus {
  opacity: 1;
}

@keyframes Toastify__trackProgress {
  0% {
    transform: scaleX(1);
  }
  100% {
    transform: scaleX(0);
  }
}
.Toastify__progress-bar {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: var(--toastify-z-index);
  opacity: 0.7;
  transform-origin: left;
  border-bottom-left-radius: var(--toastify-toast-bd-radius);
}
.Toastify__progress-bar--animated {
  animation: Toastify__trackProgress linear 1 forwards;
}
.Toastify__progress-bar--controlled {
  transition: transform 0.2s;
}
.Toastify__progress-bar--rtl {
  right: 0;
  left: initial;
  transform-origin: right;
  border-bottom-left-radius: initial;
  border-bottom-right-radius: var(--toastify-toast-bd-radius);
}
.Toastify__progress-bar--wrp {
  position: absolute;
  bottom: 0;
  left: 0;
  width: 100%;
  height: 5px;
  border-bottom-left-radius: var(--toastify-toast-bd-radius);
}
.Toastify__progress-bar--wrp[data-hidden=true] {
  opacity: 0;
}
.Toastify__progress-bar--bg {
  opacity: var(--toastify-color-progress-bgo);
  width: 100%;
  height: 100%;
}

.Toastify__spinner {
  width: 20px;
  height: 20px;
  box-sizing: border-box;
  border: 2px solid;
  border-radius: 100%;
  border-color: var(--toastify-spinner-color-empty-area);
  border-right-color: var(--toastify-spinner-color);
  animation: Toastify__spin 0.65s linear infinite;
}

@keyframes Toastify__bounceInRight {
  from, 60%, 75%, 90%, to {
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  from {
    opacity: 0;
    transform: translate3d(3000px, 0, 0);
  }
  60% {
    opacity: 1;
    transform: translate3d(-25px, 0, 0);
  }
  75% {
    transform: translate3d(10px, 0, 0);
  }
  90% {
    transform: translate3d(-5px, 0, 0);
  }
  to {
    transform: none;
  }
}
@keyframes Toastify__bounceOutRight {
  20% {
    opacity: 1;
    transform: translate3d(-20px, var(--y), 0);
  }
  to {
    opacity: 0;
    transform: translate3d(2000px, var(--y), 0);
  }
}
@keyframes Toastify__bounceInLeft {
  from, 60%, 75%, 90%, to {
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    opacity: 0;
    transform: translate3d(-3000px, 0, 0);
  }
  60% {
    opacity: 1;
    transform: translate3d(25px, 0, 0);
  }
  75% {
    transform: translate3d(-10px, 0, 0);
  }
  90% {
    transform: translate3d(5px, 0, 0);
  }
  to {
    transform: none;
  }
}
@keyframes Toastify__bounceOutLeft {
  20% {
    opacity: 1;
    transform: translate3d(20px, var(--y), 0);
  }
  to {
    opacity: 0;
    transform: translate3d(-2000px, var(--y), 0);
  }
}
@keyframes Toastify__bounceInUp {
  from, 60%, 75%, 90%, to {
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  from {
    opacity: 0;
    transform: translate3d(0, 3000px, 0);
  }
  60% {
    opacity: 1;
    transform: translate3d(0, -20px, 0);
  }
  75% {
    transform: translate3d(0, 10px, 0);
  }
  90% {
    transform: translate3d(0, -5px, 0);
  }
  to {
    transform: translate3d(0, 0, 0);
  }
}
@keyframes Toastify__bounceOutUp {
  20% {
    transform: translate3d(0, calc(var(--y) - 10px), 0);
  }
  40%, 45% {
    opacity: 1;
    transform: translate3d(0, calc(var(--y) + 20px), 0);
  }
  to {
    opacity: 0;
    transform: translate3d(0, -2000px, 0);
  }
}
@keyframes Toastify__bounceInDown {
  from, 60%, 75%, 90%, to {
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
  }
  0% {
    opacity: 0;
    transform: translate3d(0, -3000px, 0);
  }
  60% {
    opacity: 1;
    transform: translate3d(0, 25px, 0);
  }
  75% {
    transform: translate3d(0, -10px, 0);
  }
  90% {
    transform: translate3d(0, 5px, 0);
  }
  to {
    transform: none;
  }
}
@keyframes Toastify__bounceOutDown {
  20% {
    transform: translate3d(0, calc(var(--y) - 10px), 0);
  }
  40%, 45% {
    opacity: 1;
    transform: translate3d(0, calc(var(--y) + 20px), 0);
  }
  to {
    opacity: 0;
    transform: translate3d(0, 2000px, 0);
  }
}
.Toastify__bounce-enter--top-left, .Toastify__bounce-enter--bottom-left {
  animation-name: Toastify__bounceInLeft;
}
.Toastify__bounce-enter--top-right, .Toastify__bounce-enter--bottom-right {
  animation-name: Toastify__bounceInRight;
}
.Toastify__bounce-enter--top-center {
  animation-name: Toastify__bounceInDown;
}
.Toastify__bounce-enter--bottom-center {
  animation-name: Toastify__bounceInUp;
}

.Toastify__bounce-exit--top-left, .Toastify__bounce-exit--bottom-left {
  animation-name: Toastify__bounceOutLeft;
}
.Toastify__bounce-exit--top-right, .Toastify__bounce-exit--bottom-right {
  animation-name: Toastify__bounceOutRight;
}
.Toastify__bounce-exit--top-center {
  animation-name: Toastify__bounceOutUp;
}
.Toastify__bounce-exit--bottom-center {
  animation-name: Toastify__bounceOutDown;
}

@keyframes Toastify__zoomIn {
  from {
    opacity: 0;
    transform: scale3d(0.3, 0.3, 0.3);
  }
  50% {
    opacity: 1;
  }
}
@keyframes Toastify__zoomOut {
  from {
    opacity: 1;
  }
  50% {
    opacity: 0;
    transform: translate3d(0, var(--y), 0) scale3d(0.3, 0.3, 0.3);
  }
  to {
    opacity: 0;
  }
}
.Toastify__zoom-enter {
  animation-name: Toastify__zoomIn;
}

.Toastify__zoom-exit {
  animation-name: Toastify__zoomOut;
}

@keyframes Toastify__flipIn {
  from {
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    animation-timing-function: ease-in;
    opacity: 0;
  }
  40% {
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    animation-timing-function: ease-in;
  }
  60% {
    transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    opacity: 1;
  }
  80% {
    transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
  }
  to {
    transform: perspective(400px);
  }
}
@keyframes Toastify__flipOut {
  from {
    transform: translate3d(0, var(--y), 0) perspective(400px);
  }
  30% {
    transform: translate3d(0, var(--y), 0) perspective(400px) rotate3d(1, 0, 0, -20deg);
    opacity: 1;
  }
  to {
    transform: translate3d(0, var(--y), 0) perspective(400px) rotate3d(1, 0, 0, 90deg);
    opacity: 0;
  }
}
.Toastify__flip-enter {
  animation-name: Toastify__flipIn;
}

.Toastify__flip-exit {
  animation-name: Toastify__flipOut;
}

@keyframes Toastify__slideInRight {
  from {
    transform: translate3d(110%, 0, 0);
    visibility: visible;
  }
  to {
    transform: translate3d(0, var(--y), 0);
  }
}
@keyframes Toastify__slideInLeft {
  from {
    transform: translate3d(-110%, 0, 0);
    visibility: visible;
  }
  to {
    transform: translate3d(0, var(--y), 0);
  }
}
@keyframes Toastify__slideInUp {
  from {
    transform: translate3d(0, 110%, 0);
    visibility: visible;
  }
  to {
    transform: translate3d(0, var(--y), 0);
  }
}
@keyframes Toastify__slideInDown {
  from {
    transform: translate3d(0, -110%, 0);
    visibility: visible;
  }
  to {
    transform: translate3d(0, var(--y), 0);
  }
}
@keyframes Toastify__slideOutRight {
  from {
    transform: translate3d(0, var(--y), 0);
  }
  to {
    visibility: hidden;
    transform: translate3d(110%, var(--y), 0);
  }
}
@keyframes Toastify__slideOutLeft {
  from {
    transform: translate3d(0, var(--y), 0);
  }
  to {
    visibility: hidden;
    transform: translate3d(-110%, var(--y), 0);
  }
}
@keyframes Toastify__slideOutDown {
  from {
    transform: translate3d(0, var(--y), 0);
  }
  to {
    visibility: hidden;
    transform: translate3d(0, 500px, 0);
  }
}
@keyframes Toastify__slideOutUp {
  from {
    transform: translate3d(0, var(--y), 0);
  }
  to {
    visibility: hidden;
    transform: translate3d(0, -500px, 0);
  }
}
.Toastify__slide-enter--top-left, .Toastify__slide-enter--bottom-left {
  animation-name: Toastify__slideInLeft;
}
.Toastify__slide-enter--top-right, .Toastify__slide-enter--bottom-right {
  animation-name: Toastify__slideInRight;
}
.Toastify__slide-enter--top-center {
  animation-name: Toastify__slideInDown;
}
.Toastify__slide-enter--bottom-center {
  animation-name: Toastify__slideInUp;
}

.Toastify__slide-exit--top-left, .Toastify__slide-exit--bottom-left {
  animation-name: Toastify__slideOutLeft;
  animation-timing-function: ease-in;
  animation-duration: 0.3s;
}
.Toastify__slide-exit--top-right, .Toastify__slide-exit--bottom-right {
  animation-name: Toastify__slideOutRight;
  animation-timing-function: ease-in;
  animation-duration: 0.3s;
}
.Toastify__slide-exit--top-center {
  animation-name: Toastify__slideOutUp;
  animation-timing-function: ease-in;
  animation-duration: 0.3s;
}
.Toastify__slide-exit--bottom-center {
  animation-name: Toastify__slideOutDown;
  animation-timing-function: ease-in;
  animation-duration: 0.3s;
}

@keyframes Toastify__spin {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(360deg);
  }
}

/*# sourceMappingURL=ReactToastify.css.map */
/*!*****************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/TopbarMenu/styles/TitleBarMenu.module.scss ***!
  \*****************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.TitleBarMenu-module__wrapper__DBiyL {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
  padding: 10px;
  background-color: var(--background-dark);
  border-radius: 8px;
  width: 100%;
}

.TitleBarMenu-module__menuCardsWrapper__WG84Q {
  display: flex;
  flex-wrap: wrap;
  gap: 12px;
  margin-left: auto;
  justify-content: flex-end;
  padding-right: 25px;
  margin-right: 25px;
}
/*!*********************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/TopbarMenu/styles/TitleBarMenuCard.module.scss ***!
  \*********************************************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.TitleBarMenuCard-module__wrapper__BMwmx {
  display: flex;
  align-items: center;
  padding: 8px 12px;
  border-radius: 8px;
  width: 250px;
}

.TitleBarMenuCard-module__contentWrapper__nCEpz {
  display: flex;
  align-items: center;
  width: 100%;
}

.TitleBarMenuCard-module__indicatorWrapper__OnH1r {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  margin-right: 10px;
}

.TitleBarMenuCard-module__textWrapper__DTHgx {
  display: flex;
  flex-direction: column;
  justify-content: center;
  flex-grow: 1;
}

.TitleBarMenuCard-module__topRowWrapper__lDfip {
  display: flex;
  justify-content: space-between;
  align-items: center;
  margin-bottom: 6px;
}

.TitleBarMenuCard-module__bottomRowWrapper___FG26 {
  display: flex;
  justify-content: space-between;
  align-items: center;
}

.TitleBarMenuCard-module__statusContainer__dQ6ra {
  font-size: 12px;
  border-radius: 6px;
}

.TitleBarMenuCard-module__running__qWYmp {
  background-color: rgba(60, 221, 248, 0.0784313725);
  color: #fff;
}
.TitleBarMenuCard-module__running__qWYmp .TitleBarMenuCard-module__timeRemainingText__Xz00g {
  color: #8CA0B3;
  font-size: 11px;
  padding-right: 21px;
}

.TitleBarMenuCard-module__statusRunning__C3DcG {
  background-color: rgba(60, 221, 248, 0.1098039216);
  color: #3CDEF8;
  padding: 1px 4px;
  font-weight: 500;
}

.TitleBarMenuCard-module__statusRunningValue__vtESN {
  opacity: 0.8;
}

.TitleBarMenuCard-module__finished__Xguvp {
  background-color: rgba(20, 225, 168, 0.1019607843);
  color: #fff;
}

.TitleBarMenuCard-module__statusFinished__d120G {
  background-color: rgba(50, 255, 198, 0.1019607843);
  color: #32FFC6;
  padding: 1px 4px;
  font-weight: 500;
}

.TitleBarMenuCard-module__error__b3je3 {
  background-color: rgba(255, 97, 115, 0.1019607843);
  color: #fff;
}

.TitleBarMenuCard-module__statusError__VsGDL {
  background-color: rgba(255, 97, 115, 0.1490196078);
  color: #FF6173;
  padding: 1px 4px;
  font-weight: 500;
}

.TitleBarMenuCard-module__pending__lbG5e {
  background-color: var(--popup-background);
  color: #A5ACB6;
}

.TitleBarMenuCard-module__statusPending__XMJgN {
  background-color: transparent;
  font-family: Roboto, sans-serif;
  color: #3CDEF8;
  font-weight: 500;
}

.TitleBarMenuCard-module__nodeRunningLabel__p_Tmv {
  font-size: 12px;
  white-space: nowrap;
  font-weight: 500;
  overflow: hidden;
  text-overflow: ellipsis;
  max-width: 220px;
}

.TitleBarMenuCard-module__noNodeRunningLabel__aay9n {
  font-size: 14px;
  color: #a0a0af;
}

.TitleBarMenuCard-module__pointerCursor__X79DT {
  cursor: pointer;
}
/*!***************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/TopbarMenu/styles/TitleBarTooltipContent.module.scss ***!
  \***************************************************************************************************************************************************************************************/
.TitleBarTooltipContent-module__tooltipContent__Z2FkS {
  display: flex;
  flex-direction: column;
  gap: 6px;
}

.TitleBarTooltipContent-module__tooltipRow__HDxen {
  display: flex;
  flex-direction: row;
  font-size: 0.9rem;
  color: #fff;
  line-height: 1.5;
}

.TitleBarTooltipContent-module__tooltipLabel__gDWD8 {
  font-weight: 500;
  color: #a0a0af;
  min-width: 110px;
  text-align: left;
}

.TitleBarTooltipContent-module__tooltipValue__rUYKr {
  font-weight: 500;
  color: #fff;
  text-align: left;
}
/*!*********************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/RightSidebar/styles/RightSidePanel.module.scss ***!
  \*********************************************************************************************************************************************************************************/
.RightSidePanel-module__wrapper__Seq2F {
  display: flex;
  flex-direction: column;
  height: 100%;
  width: 40px;
  z-index: 9999;
}

.RightSidePanel-module__tabContainer__zGzOX {
  border: 1px solid #42424C;
  box-sizing: border-box;
  display: flex;
  height: 100%;
  flex-direction: column;
  cursor: pointer;
  justify-content: center;
  align-items: center;
}
.RightSidePanel-module__tabContainer__zGzOX span {
  writing-mode: vertical-lr;
  color: #2CCBE5;
  font-family: Roboto, serif;
  font-size: 16px;
  font-weight: 500;
}

.RightSidePanel-module__tabContainerSelected__zj2hH {
  border: 1px solid #42424C;
  background: #28292F;
}

.RightSidePanel-module__tabContainer__zGzOX:hover {
  border: 1px solid var(--border, #42424C);
  background: #323339;
}

.RightSidePanel-module__sliderPanelWrapperLogger__CoHMl {
  right: 40px;
  position: fixed;
  height: 95vh;
  padding-bottom: 5px;
  width: 500px;
  background-color: #323339;
  color: white;
  z-index: 1000;
  transition: transform 0.3s ease;
  overflow-y: auto;
  box-shadow: -2px 0 10px rgba(0, 0, 0, 0.4);
  display: flex;
  flex-direction: column;
}

.RightSidePanel-module__sliderPanelWrapper__tG6MZ {
  right: 40px;
  position: fixed;
  height: 95vh;
  padding-bottom: 5px;
  width: 500px;
  background-color: #323339;
  color: white;
  z-index: 1000;
  transition: transform 0.3s ease;
  box-shadow: -2px 0 10px rgba(0, 0, 0, 0.4);
  display: flex;
  flex-direction: column;
}
/*!*********************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/RightSidebar/Logs/styles/LogsPanel.module.scss ***!
  \*********************************************************************************************************************************************************************************/
.LogsPanel-module__panelHeader__nQlY6 {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding-top: 20px;
  padding-left: 20px;
  font-size: 20px;
  font-weight: 400;
  color: #A5ACB6;
}

.LogsPanel-module__panelHeaderSpan__S9Xie {
  font-weight: 600;
  font-size: 16px;
}

.LogsPanel-module__panelContent__i5OH0 {
  color: #FFF;
  padding-left: 20px;
  padding-top: 5px;
  font-size: 14px;
  font-weight: 400;
}

.LogsPanel-module__logsTimestamp__T_Cr4 {
  font-weight: bolder;
  padding-top: 5px;
}

.LogsPanel-module__logsMessage__Ya8JE {
  margin-left: 10px;
  word-break: break-word;
}
/*!**************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/RightSidebar/QuamPanel/styles/QuamPanel.module.scss ***!
  \**************************************************************************************************************************************************************************************/
.QuamPanel-module__panelHeader__vp_tI {
  display: flex;
  align-items: center;
  padding-top: 20px;
  padding-left: 20px;
  font-size: 16px;
  font-weight: 400;
  color: #A5ACB6;
  gap: 15px;
}

.QuamPanel-module__panelHeaderContent__Ixu9A {
  white-space: nowrap;
  display: flex;
  flex-direction: column;
  font-size: 14px;
  font-weight: 400;
  color: #A5ACB6;
}

.QuamPanel-module__panelContent__BzCsf {
  display: flex;
  flex-direction: row;
  font-size: 14px;
  font-weight: 400;
  flex: 1;
  max-height: 50%;
}

.QuamPanel-module__trackLatestWrapper__yWo4S {
  display: flex;
  align-items: center;
  color: #A5ACB6;
  font-family: Roboto, serif;
  font-size: 14px;
  gap: 8px;
  line-height: normal;
}

.QuamPanel-module__idWrapper__M4xBG {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 12px;
}
.QuamPanel-module__idWrapper__M4xBG input {
  width: 7vw;
}

span {
  font-size: 14px;
}
/*!********************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/RightSidebar/QuamPanel/components/PanelHeader/PanelHeader.module.scss ***!
  \********************************************************************************************************************************************************************************************************/
.PanelHeader-module__panelHeader__ddkEf {
  display: flex;
  align-items: center;
  padding-top: 20px;
  padding-left: 20px;
  font-size: 16px;
  font-weight: 400;
  color: #A5ACB6;
  gap: 15px;
}

.PanelHeader-module__panelHeaderSpan__CxkC5 {
  font-weight: 600;
  font-size: 16px;
}

.PanelHeader-module__panelHeaderContent__gORz4 {
  white-space: nowrap;
  display: flex;
  flex-direction: column;
  font-size: 14px;
  font-weight: 400;
  color: #A5ACB6;
}

.PanelHeader-module__trackLatestWrapper__QETZY {
  display: flex;
  align-items: center;
  color: #A5ACB6;
  font-family: Roboto, serif;
  font-size: 14px;
  font-weight: 400;
  gap: 8px;
  line-height: normal;
}

.PanelHeader-module__idWrapper__S4ms7 {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 12px;
}
.PanelHeader-module__idWrapper__S4ms7 input {
  width: 5vw;
}

.PanelHeader-module__title__EA7Dh {
  font-size: 14px;
}
/*!****************************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/common/ui-components/common/ToggleSwitchRightPanel/ToggleSwitchRightPanel.module.scss ***!
  \****************************************************************************************************************************************************************************************************************/
.ToggleSwitchRightPanel-module__toggleSwitch__EPkKd {
  width: 36px;
  height: 12px;
  background-color: #4a4a4a;
  border-radius: 6px;
  position: relative;
  cursor: pointer;
  transition: background-color 0.3s ease;
}
.ToggleSwitchRightPanel-module__toggleSwitch__EPkKd.ToggleSwitchRightPanel-module__toggleOn__fUPeH {
  background-color: #28a745;
}
.ToggleSwitchRightPanel-module__toggleSwitch__EPkKd.ToggleSwitchRightPanel-module__toggleOff__SRiFA {
  background-color: #4a4a4a;
}

.ToggleSwitchRightPanel-module__toggleKnob___qNO4 {
  width: 18px;
  height: 18px;
  background-color: #fff;
  border-radius: 50%;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
  position: absolute;
  top: -3px;
  left: 0;
  transition: left 0.3s ease;
}
.ToggleSwitchRightPanel-module__toggleKnob___qNO4.ToggleSwitchRightPanel-module__toggleOn__fUPeH {
  left: calc(100% - 18px);
}
.ToggleSwitchRightPanel-module__toggleKnob___qNO4.ToggleSwitchRightPanel-module__toggleOff__SRiFA {
  left: 0;
}
/*!**********************************************************************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/RightSidebar/QuamPanel/components/PanelUpdates/PanelUpdates.module.scss ***!
  \**********************************************************************************************************************************************************************************************************/
.PanelUpdates-module__panelUpdates__XhqMt {
  display: flex;
  flex-direction: column;
  padding-top: 20px;
  padding-left: 20px;
  font-size: 16px;
  font-weight: 400;
  color: #A5ACB6;
}

.PanelUpdates-module__panelHeaderSpan__nWRwE {
  font-weight: 600;
  font-size: 16px;
}

.PanelUpdates-module__panelHeaderContent__QZZpK {
  display: flex;
  flex-direction: column;
  font-size: 14px;
  font-weight: 400;
  color: #A5ACB6;
}

.PanelUpdates-module__idWrapper__sgWoY {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 12px;
}
.PanelUpdates-module__idWrapper__sgWoY input {
  width: 5vw;
}

.PanelUpdates-module__trackLatestWrapper__uHqJ8 {
  display: flex;
  align-items: center;
  gap: 8px;
}
/*!**********************************************************************************************************************************************************!*\
  !*** css ./node_modules/css-loader/dist/cjs.js??ruleSet[1].rules[3].use[1]!./node_modules/sass-loader/dist/cjs.js!./src/modules/Login/Login.module.scss ***!
  \**********************************************************************************************************************************************************/
/* sidebar menu */
/* breakpoints */
.Login-module__content__LDDhW {
  display: grid;
  grid-template-columns: 1fr 500px;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 100vh;
  width: 100vw;
  background-color: #2b2c32;
  overflow: hidden;
}

.Login-module__welcomeInfo__H9o4f {
  position: relative;
  overflow: hidden;
  height: 100%;
  color: #fff;
  font-family: var(--font-family-cond), serif;
}

.Login-module__wave__nbhzu {
  position: absolute;
  min-width: 100%;
  min-height: 50%;
  top: 50%;
  bottom: 0;
}

.Login-module__welcomeContent__rJS9v {
  padding: 97px;
  font-size: 58px;
  display: flex;
  flex-direction: column;
  gap: 85px;
}

.Login-module__rightPart__liB29 {
  height: 100%;
  padding: 97px;
  background: #fff;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: space-between;
  box-sizing: border-box;
}

.Login-module__version___2JWn {
  display: flex;
  align-items: center;
  font-family: var(--font-family), serif;
  font-style: normal;
  font-weight: 400;
  line-height: 16px;
  color: rgba(33, 33, 37, 0.4);
}

.Login-module__form__Id5eo {
  position: relative;
  width: 350px;
  background: #fff;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: flex-start;
  gap: 2rem;
}

.Login-module__title__kzid8 {
  font-family: var(--font-family-cond), serif;
  font-style: normal;
  font-weight: 400;
  font-size: 24px;
}

.Login-module__inputWrapper__M1FaN label {
  color: #2b2c32;
}

.Login-module__input__JZY1x {
  background: #fff;
  color: #2b2c32;
  border: 1px solid rgba(194, 209, 214, 0.5);
  width: 100%;
}

.Login-module__loginButton__g4Ivk {
  width: 100%;
  background-color: #0fb0cb !important;
  color: white !important;
}
.Login-module__loginButton__g4Ivk:disabled {
  background-color: rgba(33, 33, 37, 0.1) !important;
  color: rgba(33, 33, 37, 0.5) !important;
}

.Login-module__errorMsg__hIKAt {
  position: absolute;
  bottom: -20px;
  line-height: 14px;
  color: var(--error);
  font-weight: 400;
  font-size: 12px;
}

/*# sourceMappingURL=data:application/json;charset=utf-8;base64, */